@@ -39,6 +39,7 @@ class ScriptLibInfo
 	const LIB_FCKEDITOR				= 'fckeditor';
 	const LIB_CKEDITOR				= 'ckeditor';
 	const LIB_ELFINDER				= 'elfinder';
+	const LIB_ELFINDER21			= 'elfinder21';			// v2.1
 	const LIB_MD5					= 'md5';
 	const LIB_MOMENT				= 'moment';
 	const LIB_SWFOBJECT				= 'swfobject';
@@ -89,6 +90,7 @@ class ScriptLibInfo
 	const LIB_JQUERY_RESPONSIVETABLE	= 'jquery.responsivetable';
 	const LIB_JQUERY_FORM			= 'jquery.form';
 	const LIB_JQUERY_UPLOADFILE		= 'jquery.uploadfile';
+	const LIB_JQUERY_JCROP			= 'jquery.jcrop';
 	
 	// Magic3管理画面専用jQueryプラグイン
 	const LIB_JQUERY_M3_SLIDEPANEL		= 'jquery.m3slidepanel';		// スライドパネル
@@ -126,6 +128,7 @@ class ScriptLibInfo
 	const JQUERY_RESPONSIVETABLE_VER	= '5.0.4';
 	const JQUERY_FORM_VER			= '3.51.0';
 	const JQUERY_UPLOADFILE_VER		= '3.1.10';
+	const JQUERY_JCROP_VER			= '0.9.12';
 	// その他ライブラリバージョン
 	const CODEMIRROR_VER			= '3.1';
 	
@@ -217,6 +220,8 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 	const JQUERY_FORM_FILENAME			= 'jquery/jquery.form.min.js';
 	const JQUERY_UPLOADFILE_FILENAME	= 'jquery/uploadfile/jquery.uploadfile.js';
 	const JQUERY_UPLOADFILE_CSS			= 'jquery/uploadfile/uploadfile.css';
+	const JQUERY_JCROP_FILENAME			= 'jquery/jcrop0.9.12/jquery.Jcrop.js';
+	const JQUERY_JCROP_CSS				= 'jquery/jcrop0.9.12/jquery.Jcrop.css';
 	
 	// Magic3管理画面jQueryプラグインのファイル名
 	const JQUERY_M3_SLIDEPANEL_FILENAME	= 'jquery/jquery.m3slidepanel.js';	// スライドパネル
@@ -252,6 +257,7 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 	const JQUERY_RESPONSIVETABLE_URL	= 'http://gergeo.se/RWD-Table-Patterns';
 	const JQUERY_FORM_URL				= 'http://malsup.com/jquery/form/';
 	const JQUERY_UPLOADFILE_URL			= 'https://github.com/hayageek/jquery-upload-file/';
+	const JQUERY_JCROP_URL				= 'http://deepliquid.com/content/Jcrop.html';
 	
 	// ディレクトリ名
 	const FCKEDITOR_DIRNAME				= 'fckeditor2.6.6';				// FCKEditor
@@ -265,20 +271,26 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 	const FCKEDITOR_FILENAME		= 'fckeditor2.6.6/fckeditor.js';			// FCKEditor
 	const CKEDITOR_FILENAME			= 'ckeditor4.4.2/ckeditor.js';				// CKEditor
 	
-	const ELFINDER_FILENAME			= 'elfinder-2.0/js/elfinder.min.js';		// elFinder
+	// elFinder v2.0版
+/*	const ELFINDER_FILENAME			= 'elfinder-2.0/js/elfinder.full.js';		// elFinder
 	const ELFINDER_LANG_FILENAME	= 'elfinder-2.0/js/i18n/elfinder.ja.js';	// elFinder言語ファイル
 	const ELFINDER_CSS				= 'elfinder-2.0/css/elfinder.full.css';		// elFinder CSS
-	//const ELFINDER_CSS				= 'elfinder-2.0/css/elfinder.min.css';		// elFinder CSS
 	const ELFINDER_OPTION_CSS		= 'elfinder-2.0/css/theme.css';				// elFinder CSS
 	const ELFINDER_THEME_CSS		= 'elfinder-2.0/theme/smoothness/jquery-ui.custom.min.css';		// テーマファイル
-/*
-	const ELFINDER_FILENAME			= 'elfinder-2.1/js/elfinder.min.js';		// elFinder
+	*/
+	const ELFINDER_FILENAME			= 'elfinder-2.1/js/elfinder.full.js';		// elFinder
 	const ELFINDER_LANG_FILENAME	= 'elfinder-2.1/js/i18n/elfinder.ja.js';	// elFinder言語ファイル
 	const ELFINDER_CSS				= 'elfinder-2.1/css/elfinder.full.css';		// elFinder CSS
-	//const ELFINDER_CSS				= 'elFinder-2.0/css/elfinder.min.css';		// elFinder CSS
 	const ELFINDER_OPTION_CSS		= 'elfinder-2.1/css/theme.css';				// elFinder CSS
 	const ELFINDER_THEME_CSS		= 'elfinder-2.1/theme/smoothness/jquery-ui.custom.min.css';		// テーマファイル
-*/
+
+	// elFinder v2.1版
+	const ELFINDER21_FILENAME		= 'elfinder-2.1/js/elfinder.full.js';		// elFinder
+	const ELFINDER21_LANG_FILENAME	= 'elfinder-2.1/js/i18n/elfinder.ja.js';	// elFinder言語ファイル
+	const ELFINDER21_CSS			= 'elfinder-2.1/css/elfinder.full.css';		// elFinder CSS
+	const ELFINDER21_OPTION_CSS		= 'elfinder-2.1/css/theme.css';				// elFinder CSS
+	const ELFINDER21_THEME_CSS		= 'elfinder-2.1/theme/smoothness/jquery-ui.custom.min.css';		// テーマファイル
+
 	const MD5_FILENAME				= 'md5.js';									// MD5
 	const MOMENT_FILENAME			= 'moment-with-locales-2.9.0.js';			// Moment.js
 	const SWFOBJECT_FILENAME		= 'swfobject/swfobject.js';					// swfobject
@@ -295,7 +307,7 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 //	const BOOTSTRAP_DIALOG_FILENAME					= 'bootstrap/bootstrap3-dialog-1.34.1/bootstrap-dialog.js';		// Bootstrap Dialog拡張		// バグあり
 //	const BOOTSTRAP_DIALOG_CSS						= 'bootstrap/bootstrap3-dialog-1.34.1/bootstrap-dialog.css';
 	const BOOTSTRAP_DIALOG_FILENAME					= 'bootstrap/bootstrap3-dialog-1.34.0/bootstrap-dialog.js';		// Bootstrap Dialog拡張
-	const BOOTSTRAP_DIALOG_CSS						= 'bootstrap/bootstrap3-dialog-1.34.0/bootstrap-dialog.css';
+	const BOOTSTRAP_DIALOG_CSS						= 'bootstrap/bootstrap3-dialog-1.34.0/bootstrap-dialog.css';	// (未使用)
 	const NOBOOTSTRAP_CSS							= 'm3/nobootstrap/style.css';
 	const NOBOOTSTRAP_TOOLTIP_FILENAME				= 'm3/nobootstrap/tooltip.js';			// bootstrapツールチップ
 	const NOBOOTSTRAP_DROPDOWN_FILENAME				= 'm3/nobootstrap/dropdown.js';			// bootstrapドロップダウンメニュー
@@ -404,14 +416,18 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 						self::LIB_CKEDITOR				=>	array(	'script' 	=> array(self::CKEDITOR_FILENAME)),		// CKEditor
 						self::LIB_ELFINDER				=>	array(	'script' 	=> array(self::ELFINDER_FILENAME, self::ELFINDER_LANG_FILENAME),		// elFinder
 																	'css'		=> array(self::ELFINDER_THEME_CSS, self::ELFINDER_CSS, self::ELFINDER_OPTION_CSS)),	// テーマは最初に読み込む
+						self::LIB_ELFINDER21			=>	array(	'script' 	=> array(self::ELFINDER21_FILENAME, self::ELFINDER21_LANG_FILENAME),		// elFinder v2.1
+																	'css'		=> array(self::ELFINDER21_THEME_CSS, self::ELFINDER21_CSS, self::ELFINDER21_OPTION_CSS)),	// テーマは最初に読み込む
 						self::LIB_SWFOBJECT				=>	array(	'script' 	=> array(self::SWFOBJECT_FILENAME)),	// swfobject
 						self::LIB_BOOTSTRAP				=>	array(	'script' 	=> array(self::BOOTSTRAP_FILENAME),		// bootstrap
 																	'css'		=> array(self::BOOTSTRAP_CSS)),			// CSSファイル必要?
 	//					self::LIB_BOOTSTRAP				=>	array(	'script' 	=> array(self::BOOTSTRAP_FILENAME)),		// bootstrap
 						self::LIB_BOOTSTRAP_ADMIN		=>	array(	'script' 	=> array(self::BOOTSTRAP_DIALOG_FILENAME),
-																	'css'		=> array(	self::BOOTSTRAP_BOOTSWATCH_FLATLY_CSS,
+/*																	'css'		=> array(	self::BOOTSTRAP_BOOTSWATCH_FLATLY_CSS,
 																							self::BOOTSTRAP_BOOTSNIPP_LARGEDROPDOWNMENU_CSS,
-																							self::BOOTSTRAP_DIALOG_CSS)),	// Bootstrap管理画面用オプション			
+																							self::BOOTSTRAP_DIALOG_CSS)),	// Bootstrap管理画面用オプション*/
+																	'css'		=> array(	self::BOOTSTRAP_BOOTSWATCH_FLATLY_CSS,
+																							self::BOOTSTRAP_BOOTSNIPP_LARGEDROPDOWNMENU_CSS)),
 						self::LIB_NOBOOTSTRAP			=>	array(	'script' 	=> array(self::NOBOOTSTRAP_TOOLTIP_FILENAME, self::NOBOOTSTRAP_DROPDOWN_FILENAME),// Bootstrapなし管理画面用スクリプト
 																	'css'		=> array(self::NOBOOTSTRAP_CSS)),
 													
@@ -522,7 +538,11 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 																	'css'		=> array(self::JQUERY_UPLOADFILE_CSS),
 																	'url'		=> self::JQUERY_UPLOADFILE_URL,
 																	'version'	=> self::JQUERY_UPLOADFILE_VER),
-	
+						self::LIB_JQUERY_JCROP			=> array(	'script' 	=> array(self::JQUERY_JCROP_FILENAME),
+																	'css'		=> array(self::JQUERY_JCROP_CSS),
+																	'url'		=> self::JQUERY_JCROP_URL,
+																	'version'	=> self::JQUERY_JCROP_VER),
+																	
 						// Magic3管理画面専用jQueryプラグイン
 						self::LIB_JQUERY_M3_SLIDEPANEL	=>	array(	'script' 	=> array(self::JQUERY_M3_SLIDEPANEL_FILENAME)),	// スライドパネル
 						self::LIB_JQUERY_M3_DROPDOWN	=>	array(	'script' 	=> array(self::JQUERY_M3_DROPDOWN_FILENAME),	// ドロップダウンメニュー
@@ -612,6 +632,7 @@ const JQUERY_JQPLOT_CSS				= 'jquery/jqplot1.0.8/jquery.jqplot.min.css';
 		static $dependentLib = array(
 										//self::LIB_ELFINDER	=>	array(self::LIB_JQUERY_UI_WIDGETS_DIALOG, self::LIB_JQUERY_UI_WIDGETS_SLIDER),
 										self::LIB_ELFINDER	=>	array(self::LIB_BOOTSTRAP, self::LIB_JQUERY_UI_WIDGETS_DIALOG, self::LIB_JQUERY_UI_WIDGETS_SLIDER),	// 画像リサイズが実行できないバグの対応。jQuery UIよりも前にBootstrapを読ませる必要がある。(2015/1/25)
+										self::LIB_ELFINDER21	=>	array(self::LIB_BOOTSTRAP, self::LIB_JQUERY_UI_WIDGETS_DIALOG, self::LIB_JQUERY_UI_WIDGETS_SLIDER),	// 画像リサイズが実行できないバグの対応。jQuery UIよりも前にBootstrapを読ませる必要がある。(2015/1/25)
 										self::LIB_JQUERY_TIMEPICKER	=>	array(self::LIB_JQUERY_UI),	// JQUERY_TIMEPICKERはJQUERY_UIを使用する
 										self::LIB_JQUERY_UPLOADFILE =>	array(self::LIB_JQUERY_FORM),
 										self::LIB_JQUERY_FULLCALENDAR	=> array(self::LIB_MOMENT)
