@@ -12,7 +12,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    Release 2.10.x SVN: $Id$
+ * @version    Release 2.11.x SVN: $Id$
  * @link       http://www.magic3.org
  */
 if (defined("M3_SYSTEM_DEFINE_INCLUDED")) return;
@@ -52,8 +52,8 @@ define('M3_TITLE_BRACKET_END',		'」');					// タイトルを括弧表記する
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.10.8');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2014/1/18');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.11.0');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2014/2/8');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -90,6 +90,7 @@ define('M3_TAG_MACRO_ROOT_URL',		'M3_ROOT_URL');							// アプリケーショ
 define('M3_TAG_MACRO_IMG_URL',		'M3_IMG_URL');							// 画像URLを示すマクロ
 define('M3_TAG_MACRO_LINK_URL',		'M3_LINK_URL');							// リンク先URLを示すマクロ
 define('M3_TAG_MACRO_WIDGET_URL',	'M3_WIDGET_URL');						// 個別のウィジェットのルートURLを示すマクロ
+define('M3_TAG_MACRO_WIDGET_CSS_ID',	'M3_WIDGET_CSS_ID');				// 個別のウィジェットのCSS用IDを示すマクロ
 define('M3_TAG_MACRO_EMOJI_CODE',	'M3_EMOJI');							// 絵文字コード
 define('M3_TAG_MACRO_SEPARATOR',	'M3_$');								// テキストデータセパレータ
 define('M3_TAG_MACRO_SITE_KEY',		'SITE_');								// サイト定義置換キー
@@ -350,6 +351,7 @@ define('M3_REQUEST_CMD_LOGIN',      				'login');				// ログイン
 define('M3_REQUEST_CMD_LOGOUT',      				'logout');				// ログアウト
 define('M3_REQUEST_CMD_CHANGE_TEMPLATE',			'changetemplate');		// テンプレートの変更
 define('M3_REQUEST_CMD_RSS',						'rss');					// RSS配信
+define('M3_REQUEST_CMD_CSS',						'css');					// CSS生成
 // 共通
 define('M3_REQUEST_VALUE_ON',						'on');					// on値
 define('M3_REQUEST_VALUE_OFF',						'off');					// off値
