@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -424,6 +424,15 @@ class EnvManager extends Core
 		}
 		return $path;
 	}
+	/**
+	 * 非公開リソースディレクトリへのパスを取得
+	 *
+	 * @return string			パス
+	 */
+	public function getPrivateResourcePath()
+	{
+		return M3_SYSTEM_INCLUDE_PATH . DIRECTORY_SEPARATOR . 'etc';
+	}
 	/**
 	 * widgetsディレクトリへのパスを取得
 	 *
@@ -985,6 +994,26 @@ class EnvManager extends Core
 	{
 		return $this->calcRelativePath($this->getSystemRootPath(), $path);
 	}
+	/**
+	 * URLから絶対パスを取得
+	 *
+	 * @param string $url	指定URL
+	 * @return string		絶対パス
+	 */
+	public function getAbsolutePath($url)
+	{
+		return $this->getSystemRootPath() . $this->getRelativePathToSystemRootUrl($url);
+	}
+	/**
+	 * フルパスからURLを取得
+	 *
+	 * @param string $path	指定パス
+	 * @return string		URL
+	 */
+	public function getUrlToPath($path)
+	{
+		return $this->getRootUrl() . $this->calcRelativePath($this->getSystemRootPath(), $path);
+	}
 	/**
 	 * マクロ変換したパスを取得
 	 *
