@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -30,6 +30,9 @@ class ImageManager extends Core
 	const DEFAULT_SITE_LOGO_BASE = 'logo';		// デフォルトのサイトロゴファイル名ベース
 	const DEFAULT_AVATAR_BASE = 'default';		// デフォルトのアバターファイル名ベース
 	const NOT_AVAILABLE_HEAD = 'notavailable_';		// 設定画像がない場合の表示画像のファイル名ヘッダ部
+	const PARSE_IMAGE_FORMAT = '/(\d+)([xX]?)(\d*)(.*)\.(gif|png|jpg|jpeg|bmp)$/i';		// 画像フォーマット解析用
+//	const PARSE_IMAGE_FORMAT_TYPE = '/(.*?)\s*=\s*(\d+)([xX]?)(\d*)(.*)\.(gif|png|jpg|jpeg|bmp)$/i';		// 画像フォーマットタイプ解析用
+	const PARSE_IMAGE_FORMAT_TYPE = '/(.*?)\s*=\s*(\d+)(.*)\.(gif|png|jpg|jpeg|bmp)$/i';		// 画像フォーマットタイプ解析用
 	// DB定義値
 	const CF_SITE_LOGO_FILENAME	= 'site_logo_filename';		// サイトロゴファイル
 	const CF_SITE_LOGO_FORMAT	= 'site_logo_format';		// サイトロゴフォーマット
@@ -162,30 +165,96 @@ class ImageManager extends Core
 	/**
 	 * システム共通サムネールフォーマットを取得
 	 *
+	 * @param int $filterType		画像フィルタータイプ(0=すべて、1=クロップ画像(c)のみ、10=最大アイキャッチ画像)
 	 * @return array				フォーマット
 	 */
-	function getAllSystemDefaultThumbFormat()
+	function getSystemThumbFormat($filterType = 0)
 	{
 		global $gSystemManager;
 		
-		$format = $gSystemManager->getSystemConfig(self::CF_THUMB_FORMAT);		// サムネールフォーマット
-		$formatArray = explode(';', $format);
-		return $formatArray;
+		// 画像のフォーマットを取得
+		$formatArray = explode(';', $gSystemManager->getSystemConfig(self::CF_THUMB_FORMAT));
+		
+		$formats = array();
+		switch ($filterType){
+		case 0:
+		default:
+			$formats = $formatArray;
+			break;
+		case 1:		// クロップ画像(c)のみ
+			for ($i = 0; $i < count($formatArray); $i++){
+				$format = trim($formatArray[$i]);
+				$ret = $this->parseImageFormat($format, $imageType, $imageAttr, $imageSize);
+				if ($ret){
+					if ($imageAttr == 'c') $formats[] = $format;
+				}
+			}
+			break;
+		case 10:	// 最大アイキャッチ画像
+			$format = trim($formatArray[count($formatArray) -1]);		// 最後のフォーマットを取得
+			$formats[] = $format;
+			break;
+		}
+		return $formats;
 	}
 	/**
 	 * システム共通サムネールのファイル名を取得
 	 *
 	 * @param string $contentId		コンテンツID
-	 * @return array				画像ファイル名
+	 * @param int $filterType		画像フィルタータイプ(0=すべて、1=クロップ画像(c)のみ、10=最大アイキャッチ画像)
+	 * @return array				画像ファイル名の配列と画像フォーマットの配列
 	 */
-	function getSystemDefaultThumbFilename($contentId)
+	function getSystemThumbFilename($contentId, $filterType = 0)
 	{
 		$filenameArray = array();
-		$formatArray = $this->getAllSystemDefaultThumbFormat();
+		$formatArray = $this->getSystemThumbFormat($filterType);
 		for ($i = 0; $i < count($formatArray); $i++){
 			$filenameArray[] = $contentId . '_' . $formatArray[$i];
 		}
-		return $filenameArray;
+		return array($filenameArray, $formatArray);
+	}
+	/**
+	 * サムネールタイプからシステム共通サムネールのファイル名を取得
+	 *
+	 * @param string $filenames		取得対象のファイル名(「;」区切り)
+	 * @param string $thumbTypeDef	サムネール画像タイプ定義
+	 * @param string $thumbType		サムネール画像タイプ(s,m,l等)
+	 * @return string				ファイル名
+	 */
+	function getSystemThumbFilenameByType($filenames, $thumbTypeDef = '', $thumbType = '')
+	{
+		static $savedThumbTypeDef = '';
+		static $thumbTypeArray;
+		
+		// 引数エラーチェック
+		if (empty($filenames)) return '';
+		
+		$thumbFilename = '';
+		$thumbFilenameArray = explode(';', $filenames);
+		$defaultThumbFilename = $thumbFilenameArray[count($thumbFilenameArray) -1];	// 最大サイズをデフォルト画像とする
+		
+		if (!empty($thumbTypeDef)){			// サイズ指定の場合
+			// コンテンツIDを取得
+			list($contentId, $tmp) = explode('_', $defaultThumbFilename);
+
+			// サムネールタイプを解析
+			if ($thumbTypeDef != $savedThumbTypeDef){
+				$thumbTypeArray = $this->parseFormatType($thumbTypeDef);// サムネールタイプ
+				$savedThumbTypeDef = $thumbTypeDef;
+			}
+
+			if (empty($thumbType)){
+				// サムネールタイプが設定されていない場合は最大サイズを取得
+				$thumbFilename = $contentId . '_' . end($thumbTypeArray);
+			} else {					
+				$thumbFilename = $contentId . '_' . $thumbTypeArray[$thumbType];
+			}
+			
+			// 作成されていない画像の場合はデフォルト画像を設定
+			if (!in_array($thumbFilename, $thumbFilenameArray)) $thumbFilename = '';
+		}
+		if (empty($thumbFilename)) $thumbFilename = $defaultThumbFilename;	// デフォルト画像
+		return $thumbFilename;
 	}
 	/**
 	 * システム共通のサムネール画像のURLを取得
@@ -276,6 +345,50 @@ class ImageManager extends Core
 			}
 		}
 	}
+	/**
+	 * システム共通の非公開サムネール画像のパスを取得
+	 *
+	 * @param string     $contentType	コンテンツタイプ
+	 * @param int        $deviceType	デバイスタイプ(0=PC、1=携帯、2=スマートフォン)
+	 * @param string     $filename		ファイル名(空のときは格納ディレクトリを返す)
+	 * @param string     $notAvailableFileType	ファイルが見つからない場合の代替ファイルのタイプ(ogp=OGP用サムネール)
+	 * @return string					画像パス
+	 */
+	function getSystemPrivateThumbPath($contentType, $deviceType, $filename = '', $notAvailableFileType = '')
+	{
+		global $gEnvManager;
+				
+		switch ($deviceType){
+			case 0:		// PC
+			default:
+				$deviceDir = '';
+				break;
+			case 1:		// 携帯
+				$deviceDir = '/m';
+				break;
+			case 2:		// スマートフォン
+				$deviceDir = '/s';
+				break;
+		}
+		
+		$destDir = $gEnvManager->getIncludePath() . self::CONTENT_DIR . $contentType . $deviceDir . self::THUMBNAIL_DIR;		// 画像格納用のディレクトリ
+		
+		if (empty($notAvailableFileType)){
+			if (empty($filename)){
+				return $destDir;
+			} else {
+				return $destDir . DIRECTORY_SEPARATOR . $filename;
+			}
+		} else {		// 画像が見つからない場合の画像タイプが指定されているとき
+			// ファイルとして扱う
+			$path = $destDir . DIRECTORY_SEPARATOR . $filename;
+			if (!is_dir($path) && is_readable($path)){
+				return $destDir . DIRECTORY_SEPARATOR . $filename;
+			} else {
+				return $this->getNotAvailableImagePath($notAvailableFileType);
+			}
+		}
+	}
 	/**
 	 * デフォルトのサムネールを作成
 	 *
@@ -298,6 +411,17 @@ class ImageManager extends Core
 		$ret = $this->createThumb($path, $destPath, $this->defaultThumbSize, IMAGETYPE_PNG);
 		return $ret;
 	}
+	/**
+	 * フォーマットからサムネール画像のファイル名を取得
+	 *
+	 * @param string $contentId		コンテンツID
+	 * @param string $format		画像フォーマット
+	 * @return string				画像URL
+	 */
+	function getThumbFilename($contentId, $format)
+	{
+		return $contentId . '_' . $format;
+	}
 	/**
 	 * サムネール画像のURLを取得
 	 *
@@ -325,7 +449,7 @@ class ImageManager extends Core
 		return $gEnvManager->getResourcePath() . self::CONTENT_DIR . $contentType . self::THUMBNAIL_DIR . DIRECTORY_SEPARATOR . $contentId . '_' . $this->defaultThumbType . '.' . $this->defaultThumbExt;
 	}
 	/**
-	 * サムネールを作成
+	 * サムネールを作成(自動クロップ機能付き)
 	 *
 	 * @param string $path		元の画像ファイル
 	 * @param string $destPath	サムネールファイルパス
@@ -462,7 +586,6 @@ class ImageManager extends Core
 		$ret = imagedestroy($thumbObj);
 		return $ret;
 	}
-	
 	/**
 	 * リサイズ画像を作成
 	 *
@@ -553,6 +676,104 @@ class ImageManager extends Core
 		$destSize = array('width' => $destWidth, 'height' => $destHeight);
 		return $ret;
 	}
+	/**
+	 * クロップ画像を作成
+	 *
+	 * @param string $path		元の画像ファイル
+	 * @param int $x			クロップ位置(x座標)
+	 * @param int $y			クロップ位置(y座標)
+	 * @param int $w			クロップ位置(幅)
+	 * @param int $h			クロップ位置(高さ)
+	 * @param string $destPath	出力画像ファイルパス
+	 * @param int $destWidth	出力画像幅
+	 * @param int $destHeight	出力画像高さ
+	 * @param int $type			出力画像タイプ
+	 * @param int $imageQuality	画像品質
+	 * @return bool				true=作成,false=作成失敗
+	 */
+	function createCropImage($path, $x, $y, $w, $h, $destPath, $destWidth, $destHeight, $type = IMAGETYPE_JPEG, $imageQuality = 100)
+	{
+		// 元の画像サイズを取得
+		$imageSize = @getimagesize($path);
+		if ($imageSize){
+			$imageType = $imageSize[2];
+			$srcWidth = $imageSize[0];
+			$srcHeight = $imageSize[1];
+		} else {
+			return false;
+		}
+
+		// 画像オブジェクト作成
+		switch ($imageType){
+			case IMAGETYPE_GIF:
+				$imageObj = @imagecreatefromgif($path);
+				break;
+			case IMAGETYPE_JPEG:
+				$imageObj = @imagecreatefromjpeg($path);
+				break;
+			case IMAGETYPE_PNG:
+				$imageObj = @imagecreatefrompng($path);
+				break;
+			default:		// 処理不可の画像タイプの場合は終了
+				return false;
+		}
+		
+		// 出力用の画像オブジェクト作成
+		$destImageObj = imagecreatetruecolor($destWidth, $destHeight);
+		
+		// 画像サイズ取得
+		$newX = $x;
+		$newY = $y;
+		$newW = $w;
+		$newH = $h;
+		if ($destWidth > $destHeight){		// 横長タイプの画像に変換の場合
+			// 横方向に拡張
+			$newW = round($h * $destWidth / $destHeight);
+			$newX = round($x + $w / 2 - $newW / 2);
+			if ($newX < 0 || $newX + $newW > $srcWidth){	// 横方向に拡張できない場合は縦を縮小
+				$newH = round($w * $destHeight / $destWidth);
+				$newY = round($y + $h / 2 - $newH / 2);
+				$newX = $x;
+				$newW = $w;
+			}
+		} else if ($destWidth < $destHeight){		// 縦長タイプの画像に変換の場合
+			// 縦方向に拡張
+			$newH = round($w * $destHeight / $destWidth);
+			$newY = round($y + $h / 2 - $newH / 2);
+			if ($newY < 0 || $newY + $newH > $srcHeight){	// 縦方向に拡張できない場合は横を縮小
+				$newW = round($h * $destWidth / $destHeight);
+				$newX = round($x + $w / 2 - $newW / 2);
+				$newY = $y;
+				$newH = $h;
+			}
+		}
+		
+		// 画像作成
+		if (!imagecopyresampled($destImageObj, $imageObj, 0, 0, $newX, $newY, $destWidth, $destHeight, $newW, $newH)){
+			imagedestroy($imageObj);
+			imagedestroy($destImageObj);
+			return false;
+		}
+		
+		// 画像ファイル出力
+		switch ($type){
+			case IMAGETYPE_GIF:
+				$ret = @imagegif($destImageObj, $destPath, $imageQuality);
+				break;
+			case IMAGETYPE_JPEG:
+				$ret = @imagejpeg($destImageObj, $destPath, $imageQuality);
+				break;
+			case IMAGETYPE_PNG:
+				//$ret = @imagepng($destImageObj, $destPath, $imageQuality);		// PNGでは$imageQualityを使用すると画像が0サイズで作成される
+				$ret = @imagepng($destImageObj, $destPath);
+				break;
+		}
+		// イメージを破棄
+		$ret = imagedestroy($imageObj);
+		$ret = imagedestroy($destImageObj);
+		
+		return $ret;
+	}
 	/**
 	 * コンテンツから先頭の画像のパスを取得
 	 *
@@ -972,7 +1193,7 @@ class ImageManager extends Core
 		return $ret;
 	}
 	/**
-	 * フォーマットから画像サイズ、画像タイプを取得
+	 * 画像フォーマットから画像サイズ、画像タイプを取得
 	 *
 	 * @param string $format		画像フォーマット
 	 * @param string $imageType		画像タイプ
@@ -984,8 +1205,8 @@ class ImageManager extends Core
 	function parseImageFormat($format, &$imageType, &$imageAttr, &$imageSize, &$imageWidthHeight = null)
 	{
 		$format = trim($format);
-		//$ret = preg_match('/(\d+)(.*)\.(gif|png|jpg|jpeg|bmp)$/i', $format, $matches);
-		$ret = preg_match('/(\d+)([xX]?)(\d*)(.*)\.(gif|png|jpg|jpeg|bmp)$/i', $format, $matches);	// 「MMxNNc.jpg」タイプのフォーマットを解析
+		//$ret = preg_match('/(\d+)([xX]?)(\d*)(.*)\.(gif|png|jpg|jpeg|bmp)$/i', $format, $matches);	// 「MMxNNc.jpg」タイプのフォーマットを解析
+		$ret = preg_match(self::PARSE_IMAGE_FORMAT, $format, $matches);		// 「MMxNNc.jpg」タイプのフォーマットを解析
 		if ($ret){
 			$imageSize = $matches[1];
 			$height = intval($matches[3]);
@@ -1018,6 +1239,32 @@ class ImageManager extends Core
 		}
 		return $ret;
 	}
+	/**
+	 * 画像フォーマットタイプを解析
+	 *
+	 * @param string $formatStr 画像フォーマット
+	 * @return array			フォーマットタイプの連想配列
+	 */
+	function parseFormatType($formatStr)
+	{
+		// フォーマットを読み込む
+		$typeArray = array();
+		$lines = explode(';', $formatStr);		// アバターフォーマット
+		for ($i = 0; $i < count($lines); $i++){
+			$line = trim($lines[$i]);
+			if (!empty($line)){
+				//$ret = preg_match(, $line, $matches);
+				//'/(.*?)\s*=\s*(\d+)([xX]?)(\d*)(.*)\.(gif|png|jpg|jpeg|bmp)$/i';		// 画像フォーマットタイプ解析用
+				$ret = preg_match(self::PARSE_IMAGE_FORMAT_TYPE, $line, $matches);
+				if ($ret){
+					$imageType = $matches[1];
+					$imageFormat = $matches[2] . strtolower($matches[3]) . '.' . strtolower($matches[4]);
+					if (!empty($imageType)) $typeArray[$imageType] = $imageFormat;
+				}
+			}
+		}
+		return $typeArray;
+	}
 	/**
 	 * 画像未設定時に表示する画像のURLを取得
 	 *
