@@ -30,7 +30,7 @@ INSERT INTO _nav_item
 (107,   100,          6,        'admin_menu', 'smenudef',        0,               '',       'メニュー管理', 'メニュー管理', 'メニュー定義を管理します。'),
 (199,   0,            1,        'admin_menu', '_199',            1,               '',       '改行',                 '',                     ''),
 (200,   0,            2,        'admin_menu', '_login',          0,               '',       'システム運用',         '',                     ''),
-(201,   200,          0,        'admin_menu', 'userlist',        0,               '',       'ユーザ一覧',           'ユーザ一覧',           'ログイン可能なユーザを管理します。'),
+(201,   200,          0,        'admin_menu', 'userlist',        0,               '',       'ユーザ管理',           'ユーザ管理',           'ログイン可能なユーザを管理します。'),
 (202,   200,          1,        'admin_menu', 'accesslog',     0,               '',       '運用状況', '運用状況', 'サイトの運用状況を表示します。'),
 (299,   0,            3,        'admin_menu', '_299',            1,               '',       '改行',                 '',                     ''),
 (300,   0,            4,        'admin_menu', '_config',         0,               '',       'システム管理',         '',                     ''),
