@@ -44,7 +44,6 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 		$this->options['fileMode'] = 0644;            // new files mode
 		$this->options['quarantine'] = '.quarantine';  // quarantine folder name - required to check archive (must be hidden)
 		$this->options['maxArcFilesSize'] = 0;        // max allowed archive files size (0 - no limit)
-		$this->options['icon']     = (defined('ELFINDER_IMG_PARENT_URL')? (rtrim(ELFINDER_IMG_PARENT_URL, '/').'/') : '').'img/volume_icon_local.png';
 	}
 	
 	/*********************************************************************/
@@ -61,6 +60,16 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 		$this->aroot = realpath($this->root);
 		$root = $this->stat($this->root);
 		
+		if ($this->options['quarantine']) {
+			$this->attributes[] = array(
+				'pattern' => '~^'.preg_quote(DIRECTORY_SEPARATOR.$this->options['quarantine']).'$~',
+				'read'    => false,
+				'write'   => false,
+				'locked'  => true,
+				'hidden'  => true
+			);
+		}
+		
 		// chek thumbnails path
 		if ($this->options['tmbPath']) {
 			$this->options['tmbPath'] = strpos($this->options['tmbPath'], DIRECTORY_SEPARATOR) === false
@@ -83,35 +92,17 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 		}
 
 		// check quarantine dir
-		$this->quarantine = '';
 		if (!empty($this->options['quarantine'])) {
-			if (is_dir($this->options['quarantine'])) {
-				if (is_writable($this->options['quarantine'])) {
-					$this->quarantine = $this->options['quarantine'];
-				}
-				$this->options['quarantine'] = '';
-			} else {
-				$this->quarantine = $this->root.DIRECTORY_SEPARATOR.$this->options['quarantine'];
-				if ((!is_dir($this->quarantine) && !$this->_mkdir($this->root, $this->options['quarantine'])) || !is_writable($this->quarantine)) {
-					$this->options['quarantine'] = $this->quarantine = '';
-				}
+			$this->quarantine = $this->root.DIRECTORY_SEPARATOR.$this->options['quarantine'];
+			if ((!is_dir($this->quarantine) && !$this->_mkdir($this->root, $this->options['quarantine'])) || !is_writable($this->quarantine)) {
+				$this->archivers['extract'] = array();
+				$this->disabled[] = 'extract';
 			}
-		}
-		
-		if (!$this->quarantine) {
+		} else {
 			$this->archivers['extract'] = array();
 			$this->disabled[] = 'extract';
 		}
 		
-		if ($this->options['quarantine']) {
-			$this->attributes[] = array(
-					'pattern' => '~^'.preg_quote(DIRECTORY_SEPARATOR.$this->options['quarantine']).'$~',
-					'read'    => false,
-					'write'   => false,
-					'locked'  => true,
-					'hidden'  => true
-			);
-		}
 	}
 	
 	/*********************************************************************/
@@ -246,12 +237,7 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 	 * @author Dmitry (dio) Levashov
 	 **/
 	protected function _inpath($path, $parent) {
-		$real_path = realpath($path);
-		$real_parent = realpath($parent);
-		if ($real_path && $real_parent) {
-			return $real_path === $real_parent || strpos($real_path, $real_parent.DIRECTORY_SEPARATOR) === 0;
-		}
-		return false;
+		return $path == $parent || strpos($path, $parent.DIRECTORY_SEPARATOR) === 0;
 	}
 	
 	
@@ -289,7 +275,7 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 			// for Inheritance class ( not calling parent::configure() )
 			$this->aroot = realpath($this->root);
 		}
-		if (!$this->_inpath($path, $this->aroot)) {
+		if (!$this->_inpath(realpath($path), $this->aroot)) {
 			return $stat;
 		}
 
@@ -306,9 +292,9 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 			$stat['target'] = $target;
 			$path  = $target;
 			$lstat = lstat($path);
-			$size  = sprintf('%u', $lstat['size']);
+			$size  = $lstat['size'];
 		} else {
-			$size = sprintf('%u', @filesize($path));
+			$size = @filesize($path);
 		}
 		
 		$dir = is_dir($path);
@@ -381,8 +367,16 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 			$target = dirname($path).DIRECTORY_SEPARATOR.$target;
 		}
 		
-		if ($this->_inpath($target, $this->aroot)) {
-			$atarget = realpath($target);
+		$atarget = realpath($target);
+		
+		if (!$atarget) {
+			return false;
+		}
+		
+		$root  = $this->root;
+		$aroot = $this->aroot;
+
+		if ($this->_inpath($atarget, $this->aroot)) {
 			return $this->_normpath($this->root.DIRECTORY_SEPARATOR.substr($atarget, strlen($this->aroot)+1));
 		}
 
@@ -416,7 +410,7 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 	 * @author Dmitry (dio) Levashov
 	 **/
 	protected function _fopen($path, $mode='rb') {
-		return @fopen($path, $mode);
+		return @fopen($path, 'r');
 	}
 	
 	/**
@@ -547,10 +541,14 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 	protected function _save($fp, $dir, $name, $stat) {
 		$path = $dir.DIRECTORY_SEPARATOR.$name;
 
-		if (@file_put_contents($path, $fp, LOCK_EX) === false) {
+		if (!($target = @fopen($path, 'wb'))) {
 			return false;
 		}
 
+		while (!feof($fp)) {
+			fwrite($target, fread($fp, 8192));
+		}
+		fclose($target);
 		@chmod($path, $this->options['fileMode']);
 		clearstatcache();
 		return $path;
@@ -589,8 +587,96 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 	 * @return void
 	 **/
 	protected function _checkArchivers() {
-		$this->archivers = $this->getArchivers();
-		return;
+		if (!function_exists('exec')) {
+			$this->options['archivers'] = $this->options['archive'] = array();
+			return;
+		}
+		$arcs = array(
+			'create'  => array(),
+			'extract' => array()
+			);
+		
+		//exec('tar --version', $o, $ctar);
+		$this->procExec('tar --version', $o, $ctar);
+
+		if ($ctar == 0) {
+			$arcs['create']['application/x-tar']  = array('cmd' => 'tar', 'argc' => '-cf', 'ext' => 'tar');
+			$arcs['extract']['application/x-tar'] = array('cmd' => 'tar', 'argc' => '-xf', 'ext' => 'tar');
+			//$test = exec('gzip --version', $o, $c);
+			unset($o);
+			$test = $this->procExec('gzip --version', $o, $c);
+
+			if ($c == 0) {
+				$arcs['create']['application/x-gzip']  = array('cmd' => 'tar', 'argc' => '-czf', 'ext' => 'tgz');
+				$arcs['extract']['application/x-gzip'] = array('cmd' => 'tar', 'argc' => '-xzf', 'ext' => 'tgz');
+			}
+			unset($o);
+			//$test = exec('bzip2 --version', $o, $c);
+			$test = $this->procExec('bzip2 --version', $o, $c);
+			if ($c == 0) {
+				$arcs['create']['application/x-bzip2']  = array('cmd' => 'tar', 'argc' => '-cjf', 'ext' => 'tbz');
+				$arcs['extract']['application/x-bzip2'] = array('cmd' => 'tar', 'argc' => '-xjf', 'ext' => 'tbz');
+			}
+		}
+		unset($o);
+		//exec('zip --version', $o, $c);
+		$this->procExec('zip -v', $o, $c);
+		if ($c == 0) {
+			$arcs['create']['application/zip']  = array('cmd' => 'zip', 'argc' => '-r9', 'ext' => 'zip');
+		}
+		unset($o);
+		$this->procExec('unzip --help', $o, $c);
+		if ($c == 0) {
+			$arcs['extract']['application/zip'] = array('cmd' => 'unzip', 'argc' => '',  'ext' => 'zip');
+		} 
+		unset($o);
+		//exec('rar --version', $o, $c);
+		$this->procExec('rar --version', $o, $c);
+		if ($c == 0 || $c == 7) {
+			$arcs['create']['application/x-rar']  = array('cmd' => 'rar', 'argc' => 'a -inul', 'ext' => 'rar');
+			$arcs['extract']['application/x-rar'] = array('cmd' => 'rar', 'argc' => 'x -y',    'ext' => 'rar');
+		} else {
+			unset($o);
+			//$test = exec('unrar', $o, $c);
+			$test = $this->procExec('unrar', $o, $c);
+			if ($c==0 || $c == 7) {
+				$arcs['extract']['application/x-rar'] = array('cmd' => 'unrar', 'argc' => 'x -y', 'ext' => 'rar');
+			}
+		}
+		unset($o);
+		//exec('7za --help', $o, $c);
+		$this->procExec('7za --help', $o, $c);
+		if ($c == 0) {
+			$arcs['create']['application/x-7z-compressed']  = array('cmd' => '7za', 'argc' => 'a', 'ext' => '7z');
+			$arcs['extract']['application/x-7z-compressed'] = array('cmd' => '7za', 'argc' => 'e -y', 'ext' => '7z');
+			
+			if (empty($arcs['create']['application/x-gzip'])) {
+				$arcs['create']['application/x-gzip'] = array('cmd' => '7za', 'argc' => 'a -tgzip', 'ext' => 'tar.gz');
+			}
+			if (empty($arcs['extract']['application/x-gzip'])) {
+				$arcs['extract']['application/x-gzip'] = array('cmd' => '7za', 'argc' => 'e -tgzip -y', 'ext' => 'tar.gz');
+			}
+			if (empty($arcs['create']['application/x-bzip2'])) {
+				$arcs['create']['application/x-bzip2'] = array('cmd' => '7za', 'argc' => 'a -tbzip2', 'ext' => 'tar.bz');
+			}
+			if (empty($arcs['extract']['application/x-bzip2'])) {
+				$arcs['extract']['application/x-bzip2'] = array('cmd' => '7za', 'argc' => 'a -tbzip2 -y', 'ext' => 'tar.bz');
+			}
+			if (empty($arcs['create']['application/zip'])) {
+				$arcs['create']['application/zip'] = array('cmd' => '7za', 'argc' => 'a -tzip -l', 'ext' => 'zip');
+			}
+			if (empty($arcs['extract']['application/zip'])) {
+				$arcs['extract']['application/zip'] = array('cmd' => '7za', 'argc' => 'e -tzip -y', 'ext' => 'zip');
+			}
+			if (empty($arcs['create']['application/x-tar'])) {
+				$arcs['create']['application/x-tar'] = array('cmd' => '7za', 'argc' => 'a -ttar -l', 'ext' => 'tar');
+			}
+			if (empty($arcs['extract']['application/x-tar'])) {
+				$arcs['extract']['application/x-tar'] = array('cmd' => '7za', 'argc' => 'e -ttar -y', 'ext' => 'tar');
+			}
+		}
+		
+		$this->archivers = $arcs;
 	}
 
 	/**
@@ -633,13 +719,13 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 					if (is_dir($p) && $this->_findSymlinks($p)) {
 						return true;
 					} elseif (is_file($p)) {
-						$this->archiveSize += sprintf('%u', filesize($p));
+						$this->archiveSize += filesize($p);
 					}
 				}
 			}
 		} else {
 			
-			$this->archiveSize += sprintf('%u', filesize($path));
+			$this->archiveSize += filesize($path);
 		}
 		
 		return false;
@@ -764,17 +850,4 @@ class elFinderVolumeLocalFileSystem extends elFinderVolumeDriver {
 		return file_exists($path) ? $path : false;
 	}
 	
-	/******************** Over write functions *************************/
-	
-	/**
-	 * File path of local server side work file path
-	 *
-	 * @param  string $path
-	 * @return string
-	 * @author Naoki Sawada
-	 */
-	protected function getWorkFile($path) {
-		return $path;
-	}
-
 } // END class 
