@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: _installCompleteWidgetContainer.php 4220 2011-07-01 11:01:36Z fishbone $
+ * @version    SVN: $Id: _installCompleteWidgetContainer.php 5060 2012-07-23 08:42:48Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/_installBaseWidgetContainer.php');
@@ -64,8 +64,8 @@ class _installCompleteWidgetContainer extends _installBaseWidgetContainer
 			$this->gInstance->getFileManager()->backupInstaller();
 			
 			// 管理者画面へ遷移
-			//$this->gPage->redirectToDirectory();
-			$this->gPage->redirect($this->gEnv->getDefaultAdminUrl());			// Firefox5でadmin/install.phpにリダイレクトされるバグ(URLがキャッシュされる?)回避　2011/7/1
+			$this->gPage->redirectToDirectory();
+			//$this->gPage->redirect($this->gEnv->getDefaultAdminUrl());			// Firefox5でadmin/install.phpにリダイレクトされるバグ(URLがキャッシュされる?)回避　2011/7/1
 		}
 		
 		// アクセス用URLを表示
