@@ -258,7 +258,7 @@ class _installInitdbWidgetContainer extends _installBaseWidgetContainer
 				$this->gOpeLog->writeInfo(__METHOD__, $installMsg, 1000);
 				
 				// 初期設定用画面への遷移を通知
-				$guideMsg = $this->_('If you want initializing the system easily, use \'System Initialize Wizard\'. Accessing to \'System Initialize Wizard\', push ESC key on the top page.');	// システムの初期化を簡単に行うには「システム初期化ウィザード」を使用します。「システム初期化ウィザード」機能にアクセスするには、トップ画面でESCキーを押します。
+				$guideMsg = $this->_('If you want initializing the system easily, use \'System Initialize Wizard\'. Select \'Maintenance / Core Control / System Initialize Wizard\' on the main menu.');	// システムの初期化を簡単に行うには「システム初期化ウィザード」を使用します。メインメニューから「メンテナンス / コア制御 / システム初期化ウィザード」を選択します。
 				$this->gOpeLog->writeGuide(__METHOD__, $guideMsg, 3000, '', '', 'task=initwizard', true/*トップ表示*/);
 				
 				// 次の画面へ遷移
