@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -29,6 +29,8 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 	const WIDGET_CSS_CLASS_HEAD = 'm3_';			// ウィジェットCSSクラスのヘッダ部
 	const MENUBAR_TITLE = '共通設定';
 	const HELP_ADJUSTWIDGET_CONFIG = 'adjustwidget_config';			// 機能説明ヘルプ
+	const WIDGET_TAG_HEAD = 'm3widget_';			// ウィジェットの識別用タグIDヘッダ
+	const REMOVE_LIST_MARKER_CSS = "#[#M3_WIDGET_CSS_ID#] ul>li:before {\n    content: none !important;\n}\n";			// CSS(リストマーカー削除)
 	
 	/**
 	 * コンストラクタ
@@ -109,7 +111,22 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 									'url'		=> '',
 									'tagid'		=> 'menubar_other',
 									'active'	=> false,
-									'submenu'	=> array()
+									'submenu'	=> array(
+										(Object)array(
+											'name'		=> $this->_('View Control'),		// 表示制御
+											'task'		=> '',
+											'url'		=> '',
+											'tagid'		=> 'menubar_view_control',
+											'active'	=> false
+										),
+										(Object)array(
+											'name'		=> $this->_('Style'),		// スタイル
+											'task'		=> '',
+											'url'		=> '',
+											'tagid'		=> 'menubar_style',
+											'active'	=> false
+										)
+									)
 								)
 							);
 		$this->gPage->setAdminSubNavbarDef($navbarDef);
@@ -148,8 +165,9 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$showReadmore = ($request->trimValueOf('item_show_readmore') == 'on') ? 1 : 0;		// もっと読むボタンを表示するかどうか
 		$readmoreTitle = $request->trimValueOf('item_readmore_title');			// もっと読むボタンタイトル
 		$readmoreUrl = $request->trimValueOf('item_readmore_url');			// もっと読むリンク先URL
+		$removeListMarker = $request->trimCheckedValueOf('item_remove_list_marker');		// リストのマーカーを削除するかどうか
 		
-		// 「その他」設定
+		// 「表示制御」設定
 		$shared = ($request->trimValueOf('item_shared') == 'on') ? 1 : 0;		// 共通属性があるかどうか
 		$viewControlType = $request->trimValueOf('item_view_type');			// 表示制御タイプ
 		$cssClassSuffix = $request->trimValueOf('item_css_class_suffix');			// 追加CSSクラスサフィックス
@@ -186,6 +204,9 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		}
 		if (!empty($end_time)) $end_time = $this->convertToProperTime($end_time, 1/*時分フォーマット*/);
 		
+		// 「スタイル」設定
+		$css = $request->trimValueOf('item_css');		// 任意CSS
+		
 		$act = $request->trimValueOf('act');
 		$replaceNew = false;		// データを再取得するかどうか
 		if ($act == 'update'){		// 行更新のとき
@@ -198,7 +219,10 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
-				// CSSを作成
+				// その他のパラメータオブジェクトの設定値を取得
+				list($paramRemoveListMarker, $paramCss) = $this->getParamObjValue($defSerial);
+				
+				// インナーdiv用CSSを作成
 				$style = '';
 				if (!empty($this->align)) $style .= 'text-align:' . $this->align . ';';
 				if (!empty($marginTop)) $style .= 'padding-top:' . $marginTop . 'px;';
@@ -206,7 +230,23 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				if (!empty($marginLeft)) $style .= 'padding-left:' . $marginLeft . 'px;';
 				if (!empty($marginRight)) $style .= 'padding-right:' . $marginRight . 'px;';
 				
-				$ret = $this->db->updatePageDefInfo($defSerial, $style, $title, $titleVisible, $useRender, $topContent, $bottomContent, $showReadmore, $readmoreTitle, $readmoreUrl);
+				// 外部出力用CSS作成
+//				$exportCss = '';
+//				if ($removeListMarker) $exportCss = self::REMOVE_LIST_MARKER_CSS;
+
+				// ##### CSS作成 #####
+				$generateCss = '';
+				if ($removeListMarker) $generateCss .= self::REMOVE_LIST_MARKER_CSS;		// リストのマーカーを削除するCSS
+				$generateCss = rtrim($generateCss, "\r\n");
+				if (!empty($generateCss)) $generateCss .= M3_NL;
+				$generateCss .= $paramCss;			// 保存値を使用
+				
+				// その他のパラメータ
+				$paramObj = new stdClass;
+				$paramObj->removeListMarker = $removeListMarker;		// リストのマーカーを削除するかどうか
+				$paramObj->css				= $paramCss;				// 保存値を使用
+				
+				$ret = $this->db->updatePageDefInfo($defSerial, $style, $title, $titleVisible, $useRender, $topContent, $bottomContent, $showReadmore, $readmoreTitle, $readmoreUrl, serialize($paramObj), $generateCss);
 				if ($ret){		// データ追加成功のとき
 					$this->setMsg(self::MSG_GUIDANCE, $this->_('Configration updated.'));		// データを更新しました
 					$replaceNew = true;			// データを再取得
@@ -220,13 +260,12 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating configration.'));			// データ更新に失敗しました
 				}
 			}
-		} else if ($act == 'update_other'){		// 「その他」更新のとき
+		} else if ($act == 'update_view_control'){		// 「表示制御」更新のとき
 			// 期間範囲のチェック
 			if (!empty($start_date) && !empty($end_date)){
 				if (strtotime($start_date . ' ' . $start_time) >= strtotime($end_date . ' ' . $end_time)) $this->setUserErrorMsg($this->_('Invalid view term.'));		// 表示期間が不正です
 			}
-			$this->checkSingleByte($cssClassSuffix, '追加CSSクラス', true);			// 追加CSSクラスサフィックス
-			
+
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
 				// 保存データ作成
@@ -252,9 +291,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				if (!empty($this->exceptPageArray)) $exceptPageStr = implode(',', $this->exceptPageArray);
 				$updateData['pd_except_sub_id'] = $exceptPageStr;
 				
-				// 追加CSSクラス
-				$updateData['pd_suffix'] = $cssClassSuffix;			// 追加CSSクラスサフィックス
-				
+				// ページ定義を更新
 				$ret = $this->db->updatePageDefRecord($defSerial, $updateData);
 				
 				// ページ共通属性を更新
@@ -274,7 +311,64 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				}
 			}
 			// タブを選択
-			$activeTab = 'widget_other';
+			$activeTab = 'widget_view_control';
+		} else if ($act == 'update_style'){		// 「スタイル」更新のとき
+			// 入力値エラーチェック
+			$this->checkSingleByte($cssClassSuffix, '追加CSSクラス', true);			// 追加CSSクラスサフィックス
+			
+			// エラーなしの場合は、データを更新
+			if ($this->getMsgCount() == 0){
+				// その他のパラメータオブジェクトの設定値を取得
+				list($paramRemoveListMarker, $paramCss) = $this->getParamObjValue($defSerial);
+				
+				// CSS作成用のパラメータ取得
+/*				$rmListMarker = 0;
+				$ret = $this->db->getPageDef($defSerial, $row);
+				if ($ret){
+					// その他のパラメータ
+					$paramStr = $row['pd_param'];
+					if (!empty($paramStr)){
+						$paramObj = unserialize($paramStr);
+						$rmListMarker = $paramObj->removeListMarker;
+					}
+				}*/
+				
+				// ##### CSS作成 #####
+				$generateCss = '';
+				if ($paramRemoveListMarker) $generateCss .= self::REMOVE_LIST_MARKER_CSS;		// リストのマーカーを削除するCSS
+				$generateCss = rtrim($generateCss, "\r\n");
+				if (!empty($generateCss)) $generateCss .= M3_NL;
+				$generateCss .= $css;
+				
+				// その他のパラメータ
+				$paramObj = new stdClass;
+				$paramObj->removeListMarker = $paramRemoveListMarker;		// リストのマーカーを削除するかどうか
+				$paramObj->css				= $css;					// 入力されたCSSをそのまま残す
+				
+				// 追加CSSクラス
+				$updateData = array();
+				$updateData['pd_suffix']	= $cssClassSuffix;			// 追加CSSクラスサフィックス
+				$updateData['pd_css']		= $generateCss;					// CSS
+				$updateData['pd_param']		= serialize($paramObj);
+				
+				// ページ定義を更新
+				$ret = $this->db->updatePageDefRecord($defSerial, $updateData);
+				
+				if ($ret){		// データ追加成功のとき
+					$this->setMsg(self::MSG_GUIDANCE, $this->_('Configration updated.'));		// データを更新しました
+					$replaceNew = true;			// データを再取得
+					
+					// キャッシュをクリア
+					$this->gCache->clearCacheByWidgetConfigId($widgetId, $defConfigId);
+		
+					// 親ウィンドウを更新
+					$this->gPage->updateParentWindow($defSerial);
+				} else {
+					$this->setMsg(self::MSG_APP_ERR, $this->_('Failed in updating configration.'));		// データ更新に失敗しました
+				}
+			}
+			// タブを選択
+			$activeTab = 'widget_style';
 		} else {		// 初期状態
 			// 初期値設定
 			$this->align = '';
@@ -291,8 +385,9 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$showReadmore = 0;		// もっと読むボタンを表示するかどうか
 			$readmoreTitle = '';			// もっと読むボタンタイトル
 			$readmoreUrl = '';			// もっと読むリンク先URL
+			$removeListMarker = 0;		// リストのマーカーを削除するかどうか
 		
-			// 「その他」設定
+			// 「表示制御」設定
 			$shared = 0;		// 共通属性があるかどうか
 			$viewControlType = 0;		// 表示制御タイプ
 			$this->exceptPageArray = array();		// 例外ページ
@@ -300,7 +395,10 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$start_time = '';	// 公開期間開始時間
 			$end_date = '';	// 公開期間終了日
 			$end_time = '';	// 公開期間終了時間
+			
+			// 「スタイル」設定
 			$cssClassSuffix = '';			// 追加CSSクラスサフィックス
+			$css = '';
 				
 			$replaceNew = true;
 		}
@@ -344,6 +442,14 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				$readmoreTitle = $row['pd_readmore_title'];			// もっと読むボタンタイトル
 				$readmoreUrl = $row['pd_readmore_url'];			// もっと読むリンク先URL
 			
+				// その他のパラメータ
+				$paramStr = $row['pd_param'];
+				if (!empty($paramStr)){
+					$paramObj = unserialize($paramStr);
+					$removeListMarker = $paramObj->removeListMarker;		// リストのマーカーを削除するかどうか
+					$css = $paramObj->css;
+				}
+				
 				$shared = 0;		// 共通属性があるかどうか
 				if (empty($row['pd_sub_id'])) $shared = 1;	// 共通ウィジェットのとき
 				$viewControlType = $row['pd_view_control_type'];		// 表示制御タイプ
@@ -351,11 +457,16 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				$start_time = $this->convertToDispTime($row['pd_active_start_dt'], 1/*時分*/);	// 公開期間開始時間
 				$end_date = $this->convertToDispDate($row['pd_active_end_dt']);	// 公開期間終了日
 				$end_time = $this->convertToDispTime($row['pd_active_end_dt'], 1/*時分*/);	// 公開期間終了時間
-				$cssClassSuffix = $row['pd_suffix'];			// 追加CSSクラスサフィックス
 				
+				// 「スタイル」設定
+				$cssClassSuffix = $row['pd_suffix'];			// 追加CSSクラスサフィックス
+
 				//例外ページ
 				$this->exceptPageArray = array();
 				if (!empty($row['pd_except_sub_id'])) $this->exceptPageArray = explode(',', $row['pd_except_sub_id']);
+				
+				// ウィジェット用CSS ID
+				$widgetCssId = $this->gPage->getWidgetCssId($row['pd_serial'], $row['pd_id'], $row['pd_sub_id'], $row['pd_position_id']);
 			}
 		}
 		
@@ -366,44 +477,28 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$this->createPageSubIdList();
 		
 		// ナビゲーションタブ作成
-/*		$tabDef = array();
-		$tabItem = new stdClass;
-		$tabItem->name	= $this->_('Basic');		// 基本
-		$tabItem->task	= '';
-		$tabItem->url	= '#widget_config';
-		$tabItem->parent	= 0;
-		$tabItem->active	= false;
-		$tabDef[] = $tabItem;
-		$tabItem = new stdClass;
-		$tabItem->name	= $this->_('Others');
-		$tabItem->task	= '';
-		$tabItem->url	= '#widget_other';			// その他
-		$tabItem->parent	= 0;
-		$tabItem->active	= false;
-		$tabDef[] = $tabItem;
-		$tabHtml = $this->gDesign->createConfigNavTab($tabDef);
-		$this->tmpl->addVar("_widget", "nav_tab", $tabHtml);*/
 		if (empty($activeTab)){		// タブの選択
 			$this->tmpl->addVar('_widget', 'active_tab', 'widget_config');
 		} else {
 			$this->tmpl->addVar('_widget', 'active_tab', $activeTab);
 		}
 		
-		$this->tmpl->addVar("_widget", "top", $marginTop);				// 上マージン
-		$this->tmpl->addVar("_widget", "bottom", $marginBottom);		// 下マージン
-		$this->tmpl->addVar("_widget", "left", $marginLeft);			// 左マージン
-		$this->tmpl->addVar("_widget", "right", $marginRight);			// 右マージン
-		$this->tmpl->addVar("_widget", "title", $this->convertToDispString($title));				// タイトル名
+		$this->tmpl->addVar("_widget", "top", 		$this->convertToDispString($marginTop));				// 上マージン
+		$this->tmpl->addVar("_widget", "bottom", 	$this->convertToDispString($marginBottom));		// 下マージン
+		$this->tmpl->addVar("_widget", "left", 		$this->convertToDispString($marginLeft));			// 左マージン
+		$this->tmpl->addVar("_widget", "right", 	$this->convertToDispString($marginRight));			// 右マージン
+		$this->tmpl->addVar("_widget", "title", 	$this->convertToDispString($title));				// タイトル名
 		if (!empty($titleVisible)) $this->tmpl->addVar("_widget", "title_visible", 'checked');		// タイトルを表示するかどうか
 		if (!empty($useRender)) $this->tmpl->addVar("_widget", "use_render", 'checked');		// Joomla!の描画処理を使用するかどうか
-		$this->tmpl->addVar("_widget", "widget_id", $widgetId);				// ウィジェットID
+		$this->tmpl->addVar("_widget", "widget_id", $this->convertToDispString($widgetId));				// ウィジェットID
 		$this->tmpl->addVar("_widget", "top_content", $topContent);			// 補助コンテンツ(上)
 		$this->tmpl->addVar("_widget", "bottom_content", $bottomContent);			// 補助コンテンツ(下)
 		if (!empty($showReadmore)) $this->tmpl->addVar("_widget", "show_readmore_checked", 'checked');		// もっと読むボタンを表示するかどうか
-		$this->tmpl->addVar("_widget", "readmore_title", $readmoreTitle);			// もっと読むボタンタイトル
-		$this->tmpl->addVar("_widget", "readmore_url", $readmoreUrl);			// もっと読むリンク先URL
+		$this->tmpl->addVar("_widget", "readmore_title", $this->convertToDispString($readmoreTitle));			// もっと読むボタンタイトル
+		$this->tmpl->addVar("_widget", "readmore_url", $this->convertToDispString($readmoreUrl));			// もっと読むリンク先URL
+		$this->tmpl->addVar("_widget", "remove_list_marker", $this->convertToCheckedString($removeListMarker));		// リストのマーカーを削除するかどうか
 			
-		// 「その他」設定
+		// 「表示制御」設定
 		$checked = '';
 		if ($shared) $checked = 'checked';		// 共通属性があるかどうか
 		switch ($viewControlType){		// 表示制御タイプ
@@ -424,9 +519,12 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$this->tmpl->addVar("_widget", "end_date", $end_date);	// 公開期間終了日
 		$this->tmpl->addVar("_widget", "end_time", $end_time);	// 公開期間終了時間
 		
+		// 「スタイル」設定
 		$widgetOuterClass = self::WIDGET_CSS_CLASS_HEAD . str_replace('/', '_', $widgetId);
 		$this->tmpl->addVar("_widget", "css_class", $this->convertToDispString($widgetOuterClass));	// ウィジェットCSSクラス
 		$this->tmpl->addVar("_widget", "css_class_suffix", $this->convertToDispString($cssClassSuffix));			// 追加CSSクラスサフィックス
+		$this->tmpl->addVar("_widget", "widget_css_id", $this->convertToDispString($widgetCssId));	// ウィジェット用CSS ID
+		$this->tmpl->addVar("_widget", "css", $this->convertToDispString($css));
 		
 		// パス等を設定
 		$this->tmpl->addVar('_widget', 'calendar_img', $this->getUrl($this->gEnv->getRootUrl() . self::CALENDAR_ICON_FILE));	// カレンダーアイコン
@@ -527,6 +625,8 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 //		$localeText['label_widget_common_config'] = $this->_('Common Config');			// 共通設定
 		$localeText['label_config_basic'] = $this->_('Basic');			// 基本
 		$localeText['label_config_other'] = $this->_('Others');			// その他
+		$localeText['label_config_view_control'] = $this->_('View Control');			// 表示制御
+		$localeText['label_config_style'] = $this->_('Style');			// スタイル
 		$localeText['label_adjust_widget'] = $this->_('Adjust Widget Title and Contents');			// ウィジェットタイトル、位置調整
 		$localeText['label_title'] = $this->_('Title');			// タイトル名
 		$localeText['label_visible'] = $this->_('Visible');			// 表示
@@ -543,6 +643,9 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$localeText['label_readmore'] = $this->_('Readmore Button');// 「もっと読む」ボタン
 		$localeText['label_readmore_title'] = $this->_('Title:');// タイトル：
 		$localeText['label_readmore_url'] = $this->_('Url:');// URL：
+		$localeText['label_css'] = $this->_('CSS');		// CSS
+		$localeText['label_for_joomla_template'] = $this->_('Configure for Joomla! style template');		// Joomla!スタイルテンプレート用の設定
+		$localeText['label_remove_list_marker'] = $this->_('Remove list marker');		// リストのマーカーを削除
 		
 		$localeText['label_view_control'] = $this->_('View Control');// 表示制御
 		$localeText['label_shared_attr'] = $this->_('Page Shared Attribute');// ページ共通属性
@@ -558,9 +661,37 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$localeText['label_always'] = $this->_('Always');		// 常時表示
 		$localeText['label_login'] = $this->_('When user in login');		// ログイン時のみ表示
 		$localeText['label_no_login'] = $this->_('When user not in login');		// 非ログイン時のみ表示
-		$localeText['label_css_class'] = $this->_('Additional CSS Class');		// 追加CSSクラス
 		$localeText['label_update'] = $this->_('Update');// 更新
+		
+		$localeText['label_style'] = $this->_('Style');// スタイル
+		$localeText['label_widget'] = $this->_('Widget');		// ウィジェット
+		$localeText['label_element_id'] = $this->_('Element ID');		// エレメントID
+		$localeText['label_dynamic'] = $this->_('Dynamic');		// 動的
+		$localeText['label_css_class'] = $this->_('Additional CSS Class');		// 追加CSSクラス
+		
 		$this->setLocaleText($localeText);
 	}
+	/**
+	 * ページ定義からパラメータオブジェクトに格納している値を取得
+	 *
+	 * @param int $defSerial		ページ定義のシリアル番号
+	 * @return array				連想配列で値(リストのマーカーを削除するかどうか、CSS)を返す
+	 */
+	function getParamObjValue($defSerial)
+	{
+		$removeListMarker = 0;
+		$css = '';
+		$ret = $this->db->getPageDef($defSerial, $row);
+		if ($ret){
+			// その他のパラメータ
+			$paramStr = $row['pd_param'];
+			if (!empty($paramStr)){
+				$paramObj = unserialize($paramStr);
+				$removeListMarker = $paramObj->removeListMarker;
+				$css = $paramObj->css;
+			}
+		}
+		return array($removeListMarker, $css);
+	}
 }
 ?>
