@@ -8,18 +8,17 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2011 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainPageinfoWidgetContainer.php 4351 2011-09-25 01:36:31Z fishbone $
+ * @version    SVN: $Id: admin_mainPageinfoWidgetContainer.php 5903 2013-04-05 03:09:02Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainMasterBaseWidgetContainer.php');
+require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_mainMainteBaseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() . '/admin_mainDb.php');
 
-class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContainer
+class admin_mainPageinfoWidgetContainer extends admin_mainMainteBaseWidgetContainer
 {
 	private $db;	// DB接続オブジェクト
-	private $sysDb;	// システム情報取得用
 	private $pageId;	// ページID
 	private $pageSubId;	// ページサブID
 	private $defaultSubId;	// デフォルトのページサブID
@@ -37,7 +36,6 @@ class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContai
 		
 		// DBオブジェクト作成
 		$this->db = new admin_mainDb();
-		$this->sysDb = $this->gInstance->getSytemDbObject();
 		
 		// コンテンツタイプ
 		$this->contentTypeArray = array(	array(	'name' => '指定なし',					'value' => ''),
@@ -49,6 +47,7 @@ class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContai
 											array(	'name' => 'ユーザ作成コンテンツ',		'value' => M3_VIEW_TYPE_USER),
 											array(	'name' => 'イベント',					'value' => M3_VIEW_TYPE_EVENT),
 											array(	'name' => 'フォトギャラリー',			'value' => M3_VIEW_TYPE_PHOTO),
+											array(	'name' => '検索結果',					'value' => M3_VIEW_TYPE_SEARCH),
 											array(	'name' => 'ダッシュボード',				'value' => M3_VIEW_TYPE_DASHBOARD));
 	}
 	/**
@@ -107,7 +106,7 @@ class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContai
 		$this->db->getPageIdList(array($this, 'pageIdLoop'), 0/*ページID*/);
 		
 		// デフォルトのページサブIDを取得
-		$this->defaultSubId = $this->sysDb->getDefaultPageSubId($this->pageId);
+		$this->defaultSubId = $this->_db->getDefaultPageSubId($this->pageId);
 		
 		// ページサブID一覧を作成
 		$this->db->getPageSubIdList($this->pageId, ''/*言語なし*/, array($this, 'pageSubIdLoop'));
@@ -141,7 +140,7 @@ class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContai
 			if ($this->getMsgCount() == 0){
 				// デフォルトページの変更
 				$ret = true;
-				if ($default) $ret = $this->sysDb->updateDefaultPageSubId($this->pageId, $this->pageSubId);
+				if ($default) $ret = $this->_db->updateDefaultPageSubId($this->pageId, $this->pageSubId);
 				
 				// ページ情報の更新
 				if ($ret) $ret = $this->db->updatePageInfo($this->pageId, $this->pageSubId, $this->contentType,
@@ -182,7 +181,7 @@ class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContai
 		$this->db->getAllTemplateList($deviceType, array($this, 'templateIdLoop'));
 			
 		// デフォルトのページサブIDを取得
-		$this->defaultSubId = $this->sysDb->getDefaultPageSubId($this->pageId);
+		$this->defaultSubId = $this->_db->getDefaultPageSubId($this->pageId);
 		$default = '';
 		if ($this->pageSubId == $this->defaultSubId) $default = 'checked';
 		
@@ -258,7 +257,7 @@ class admin_mainPageinfoWidgetContainer extends admin_mainMasterBaseWidgetContai
 		if ($fetchedRow['pn_user_limited']) $userLimited = 'checked';
 		
 		// ページ上のウィジェット数(共通属性のウィジェット除く)
-		$refCount = $this->sysDb->getWidgetCountOnPage($this->pageId, $pid, true/*共通ウィジェット除く*/);
+		$refCount = $this->_db->getWidgetCountOnPage($this->pageId, $pid, true/*共通ウィジェット除く*/);
 		
 		$row = array(
 			'index'    => $index,			// インデックス番号
