@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: bbs_login_boxWidgetContainer.php 2004 2009-06-26 14:17:47Z fishbone $
+ * @version    SVN: $Id: bbs_login_boxWidgetContainer.php 2623 2009-12-05 12:40:38Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath()		. '/baseWidgetContainer.php');
@@ -93,7 +93,7 @@ class bbs_login_boxWidgetContainer extends BaseWidgetContainer
 			return;
 		} else if ($act == 'bbsloginbox_regmember'){			// 会員登録のとき
 			// BBSメインに会員登録を表示させる
-			$url = $this->gPage->createWidgetCmdUrl('', self::TARGET_WIDGET, self::THIS_WIDGET_ID, 'task=regist');
+			$url = $this->gPage->createWidgetCmdUrl(self::TARGET_WIDGET, self::THIS_WIDGET_ID, 'task=regist');
 			$this->gPage->redirect($url);
 			return;
 		}
