@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -32,6 +32,7 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 	// 画面
 	const TASK_ENTRY			= 'entry';				// ブログ記事(一覧)
 	const TASK_ENTRY_DETAIL		= 'entry_detail';		// ブログ記事(詳細)
+	const TASK_IMAGE			= 'image';				// ブログ記事画像
 	const TASK_HISTORY			= 'history';			// ブログ記事履歴
 	const TASK_COMMENT			= 'comment';			// ブログ記事コメント(一覧)
 	const TASK_COMMENT_DETAIL	= 'comment_detail';		// ブログ記事コメント(詳細)
@@ -87,6 +88,12 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 				$titles[] = '記事一覧';
 				$titles[] = '詳細';
 				break;
+			case self::TASK_IMAGE:			// ブログ記事画像
+				$titles[] = 'ブログ記事管理';
+				$titles[] = '記事一覧';
+				$titles[] = '詳細';
+				$titles[] = '画像';
+				break;
 			case self::TASK_HISTORY:			// ブログ記事履歴
 				$titles[] = 'ブログ記事管理';
 				$titles[] = '記事一覧';
@@ -136,6 +143,7 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 						'active'	=> (
 											$task == self::TASK_ENTRY ||				// ブログ記事(一覧)
 											$task == self::TASK_ENTRY_DETAIL ||		// ブログ記事(詳細)
+											$task == self::TASK_IMAGE ||			// ブログ記事画像
 											$task == self::TASK_HISTORY ||			// ブログ記事履歴
 											$task == self::TASK_COMMENT ||			// ブログ記事コメント(一覧)
 											$task == self::TASK_COMMENT_DETAIL		// ブログ記事コメント(詳細)
@@ -149,6 +157,7 @@ class admin_blog_mainBaseWidgetContainer extends BaseAdminWidgetContainer
 								'active'	=> (
 													$task == self::TASK_ENTRY ||			// ブログ記事(一覧)
 													$task == self::TASK_ENTRY_DETAIL ||		// ブログ記事(詳細)
+													$task == self::TASK_IMAGE ||			// ブログ記事画像
 													$task == self::TASK_HISTORY				// ブログ記事履歴
 												)
 							),
