@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -30,6 +30,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 	private $isMultiLang;			// 多言語対応画面かどうか
 	private $fieldValueArray;		// ユーザ定義フィールド入力値
 	const ICON_SIZE = 32;		// アイコンのサイズ
+	const EYECATCH_IMAGE_SIZE = 40;		// アイキャッチ画像サイズ
 	const CONTENT_TYPE = 'bg';		// 記事参照数取得用
 	const DEFAULT_LIST_COUNT = 20;			// 最大リスト表示数
 	const LINK_PAGE_COUNT		= 20;			// リンクページ数
@@ -40,6 +41,8 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 	const SEARCH_ICON_FILE = '/images/system/search16.png';		// 検索用アイコン
 	const NO_BLOG_NAME = '所属なし';		// 所属ブログなし
 	const FIELD_HEAD = 'item_';			// フィールド名の先頭文字列
+	const TAG_ID_ACTIVE_TERM = 'activeterm_button';		// 公開期間エリア表示用ボタンタグ
+	const TOOLTIP_ACTIVE_TERM = '公開期間を設定';		// 公開期間エリア表示用ボタンツールチップ
 	
 	/**
 	 * コンストラクタ
@@ -131,7 +134,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 	 */
 	function createList($request)
 	{
-		// ユーザ情報、表示言語
+		// 初期値取得
 		$defaultLangId = $this->gEnv->getDefaultLanguage();
 		
 		$act = $request->trimValueOf('act');
@@ -200,14 +203,17 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					// ##### サムネールの削除 #####
 					for ($i = 0; $i < count($delEntryInfo); $i++){
 						$infoObj = $delEntryInfo[$i];
-						$ret = blog_mainCommonDef::removeThumbnail($infoObj->entryId);
+//						$ret = blog_mainCommonDef::removeThumbnail($infoObj->entryId);
 						
 						if (!empty($infoObj->thumb)){
-							$oldFiles = explode(';', $infoObj->thumb);
-							$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $oldFiles);
+							//$oldFiles = explode(';', $infoObj->thumb);
+							//$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $oldFiles);
+							
+							// アイキャッチ画像削除
+							blog_mainCommonDef::removerEyecatchImage($infoObj->entryId);
 						}
 					}
-					
+
 					// キャッシュデータのクリア
 					for ($i = 0; $i < count($delItems); $i++){
 						$this->clearCacheBySerial($delItems[$i]);
@@ -427,11 +433,13 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					// 次の記事IDを取得
 					$nextEntryId = self::$_mainDb->getNextEntryId();
 				
-					$thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html);
-					if (empty($thumbPath) && !empty($html2)) $thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html2);		// 本文1に画像がないときは本文2を検索
-					if (!empty($thumbPath)){
-						$ret = $this->gInstance->getImageManager()->createSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $nextEntryId, $thumbPath, $destFilename);
-						if ($ret) $thumbFilename = implode(';', $destFilename);
+					if ($status == 2){		// 記事公開の場合のみアイキャッチ画像を作成
+						$thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html);
+						if (empty($thumbPath) && !empty($html2)) $thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html2);		// 本文1に画像がないときは本文2を検索
+						if (!empty($thumbPath)){
+							$ret = $this->gInstance->getImageManager()->createSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $nextEntryId, $thumbPath, $destFilename);
+							if ($ret) $thumbFilename = implode(';', $destFilename);
+						}
 					}
 				}
 				
@@ -456,7 +464,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					$reloadData = true;		// データの再ロード
 					
 					// ##### サムネールの作成 #####
-					$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
+/*					$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
 					if ($ret){
 						$entryId	= $row['be_id'];		// 記事ID
 						$html		= $row['be_html'];				// HTML
@@ -468,7 +476,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 						} else {
 							$ret = blog_mainCommonDef::removeThumbnail($entryId);
 						}
-					}
+					}*/
 					
 					// キャッシュデータのクリア
 					$this->clearCacheBySerial($this->serialNo);
@@ -535,11 +543,25 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 				// サムネール画像を取得
 				$thumbFilename = '';
 				if (($this->isMultiLang && $this->langId == $this->gEnv->getDefaultLanguage()) || !$this->isMultiLang){		// // 多言語対応の場合はデフォルト言語が選択されている場合のみ処理を行う
-					$thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html);
-					if (empty($thumbPath) && !empty($html2)) $thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html2);		// 本文1に画像がないときは本文2を検索
-					if (!empty($thumbPath)){
-						$ret = $this->gInstance->getImageManager()->createSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $this->entryId, $thumbPath, $destFilename);
-						if ($ret) $thumbFilename = implode(';', $destFilename);
+					if ($status == 2){		// 記事公開の場合のみアイキャッチ画像を作成
+						// コンテンツからアイキャッチ画像を作成
+						$thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html);
+						if (empty($thumbPath) && !empty($html2)) $thumbPath = $this->gInstance->getImageManager()->getFirstImagePath($html2);		// 本文1に画像がないときは本文2を検索
+						if (!empty($thumbPath)){
+							$ret = $this->gInstance->getImageManager()->createSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $this->entryId, $thumbPath, $destFilename);
+							if ($ret) $thumbFilename = implode(';', $destFilename);
+						}
+					
+						// 非公開ディレクトリのアイキャッチ画像をコピー
+						$ret = blog_mainCommonDef::copyEyecatchImageToPublicDir($this->entryId);
+						if ($ret){			// アイキャッチ画像をコピーした場合は、ファイル名を取得
+							// 画像ファイル名、フォーマット取得
+							list($destFilename, $formats) = $this->gInstance->getImageManager()->getSystemThumbFilename($this->entryId, 1/*クロップ画像のみ*/);
+							$thumbFilename = implode(';', $destFilename);
+						}
+					} else {		// 記事非公開の場合
+						// 公開ディレクトリのアイキャッチ画像を削除
+						blog_mainCommonDef::removerEyecatchImageInPublicDir($this->entryId);
 					}
 				}
 
@@ -559,13 +581,13 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			
 				$ret = self::$_mainDb->updateEntryItem($this->serialNo, $name, $html, $html2, $status, $this->categoryArray, $this->blogId, 
 													''/*投稿者そのまま*/, $regDt, $startDt, $endDt, $showComment, $receiveComment, $newSerial, $oldRecord, $otherParams);
-				if ($ret){
+/*				if ($ret){
 					// コンテンツに画像がなくなった場合は、サムネールを削除
 					if (empty($thumbFilename) && !empty($oldRecord['be_thumb_filename'])){
 						$oldFiles = explode(';', $oldRecord['be_thumb_filename']);
 						$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $oldFiles);
 					}
-				}
+				}*/
 				
 				if ($ret){
 					$this->setGuidanceMsg('データを更新しました');
@@ -574,7 +596,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					$this->serialNo = $newSerial;
 					$reloadData = true;		// データの再ロード
 					
-					// ##### サムネールの作成 #####
+/*					// ##### サムネールの作成 #####
 					$ret = self::$_mainDb->getEntryBySerial($this->serialNo, $row, $categoryRow);
 					if ($ret){
 						$entryId	= $row['be_id'];		// 記事ID
@@ -587,7 +609,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 						} else {
 							$ret = blog_mainCommonDef::removeThumbnail($entryId);
 						}
-					}
+					}*/
 					
 					// キャッシュデータのクリア
 					$this->clearCacheBySerial($this->serialNo);
@@ -637,12 +659,15 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					$this->setGuidanceMsg('データを削除しました');
 					
 					// ##### サムネールの削除 #####
-					$ret = blog_mainCommonDef::removeThumbnail($this->entryId);
+//					$ret = blog_mainCommonDef::removeThumbnail($this->entryId);
 					
 					// サムネールを削除
 					if (!empty($row['be_thumb_filename'])){
-						$oldFiles = explode(';', $row['be_thumb_filename']);
-						$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $oldFiles);
+//						$oldFiles = explode(';', $row['be_thumb_filename']);
+//						$this->gInstance->getImageManager()->delSystemDefaultThumb(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType, $oldFiles);
+						
+						// アイキャッチ画像削除
+						blog_mainCommonDef::removerEyecatchImage($this->entryId);
 					}
 						
 					// キャッシュデータのクリア
@@ -679,8 +704,11 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 					$this->setGuidanceMsg('データを削除しました');
 					
 					// ##### サムネールの削除 #####
-					$ret = blog_mainCommonDef::removeThumbnail($this->entryId);
+//					$ret = blog_mainCommonDef::removeThumbnail($this->entryId);
 					
+					// アイキャッチ画像削除
+					blog_mainCommonDef::removerEyecatchImage($this->entryId);
+						
 					// キャッシュデータのクリア
 					$this->clearCacheBySerial($this->serialNo);
 					
@@ -780,6 +808,15 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 						if (!empty($nextRow)) $nextSerial = $nextRow['be_serial'];
 					}
 				}
+				
+				// アイキャッチ画像
+				$iconUrl = blog_mainCommonDef::getEyecatchImageUrl($row['be_thumb_filename'], self::$_configArray[blog_mainCommonDef::CF_ENTRY_DEFAULT_IMAGE], self::$_configArray[blog_mainCommonDef::CF_THUMB_TYPE], 's'/*sサイズ画像*/) . '?' . date('YmdHis');
+				if (empty($row['be_thumb_filename'])){
+					$iconTitle = 'アイキャッチ画像未設定';
+				} else {
+					$iconTitle = 'アイキャッチ画像';
+				}
+				$eyecatchImageTag = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::EYECATCH_IMAGE_SIZE . '" height="' . self::EYECATCH_IMAGE_SIZE . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 			} else {		// データがないとき
 				$this->serialNo = 0;
 				$this->entryId = '0';		// 記事ID
@@ -873,6 +910,17 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		$this->tmpl->addVar("_widget", "end_date", $end_date);	// 公開期間終了日
 		$this->tmpl->addVar("_widget", "end_time", $end_time);	// 公開期間終了時間
 		$this->tmpl->addVar("_widget", "related_content", $relatedContent);	// 関連コンテンツ
+		$this->tmpl->addVar("_widget", "eyecatch_image", $eyecatchImageTag);		// アイキャッチ画像
+		
+		// 公開期間エリア表示ボタン
+		$activeTermButton = $this->gDesign->createTermButton(''/*同画面*/, self::TOOLTIP_ACTIVE_TERM, self::TAG_ID_ACTIVE_TERM);
+		$this->tmpl->addVar("_widget", "active_term_button", $activeTermButton);
+		$this->tmpl->addVar("_widget", "tagid_active_term", self::TAG_ID_ACTIVE_TERM);
+		if (!empty($start_date) || !empty($start_time) || !empty($end_date) || !empty($end_time)){
+			$this->tmpl->addVar('_widget', 'show_active_term_area', 'true');		// 公開期間エリアの初期の表示状態
+		} else {
+			$this->tmpl->addVar('_widget', 'show_active_term_area', 'false');		// 公開期間エリアの初期の表示状態
+		}
 		
 		// 前後エントリー移動ボタン
 		if (!empty($prevSerial)){
@@ -895,6 +943,7 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			$this->tmpl->setAttribute('add_button', 'visibility', 'visible');
 			$this->tmpl->addVar('_widget', 'preview_btn_disabled', 'disabled');// プレビューボタン使用不可
 			$this->tmpl->addVar('_widget', 'history_btn_disabled', 'disabled');// 履歴ボタン使用不可
+			$this->tmpl->addVar('_widget', 'image_btn_disabled', 'disabled');// 画像ボタン使用不可
 			$this->tmpl->addVar('cancel_button', 'new_btn_disabled', 'disabled');	// 「新規」ボタン使用不可
 			
 			// デフォルト言語を最初に登録
@@ -985,6 +1034,15 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 		}
 		$statusImg = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::ICON_SIZE . '" height="' . self::ICON_SIZE . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
 		
+		// アイキャッチ画像
+		$iconUrl = blog_mainCommonDef::getEyecatchImageUrl($fetchedRow['be_thumb_filename'], self::$_configArray[blog_mainCommonDef::CF_ENTRY_DEFAULT_IMAGE], self::$_configArray[blog_mainCommonDef::CF_THUMB_TYPE], 's'/*sサイズ画像*/) . '?' . date('YmdHis');
+		if (empty($fetchedRow['be_thumb_filename'])){
+			$iconTitle = 'アイキャッチ画像未設定';
+		} else {
+			$iconTitle = 'アイキャッチ画像';
+		}
+		$eyecatchImageTag = '<img src="' . $this->getUrl($iconUrl) . '" width="' . self::EYECATCH_IMAGE_SIZE . '" height="' . self::EYECATCH_IMAGE_SIZE . '" rel="m3help" alt="' . $iconTitle . '" title="' . $iconTitle . '" />';
+		
 		$row = array(
 			'index' => $index,		// 項目番号
 			'no' => $index + 1,													// 行番号
@@ -992,7 +1050,8 @@ class admin_blog_mainEntryWidgetContainer extends admin_blog_mainBaseWidgetConta
 			'id' => $this->convertToDispString($fetchedRow['be_id']),			// ID
 			'name' => $this->convertToDispString($fetchedRow['be_name']),		// 名前
 			'lang' => $lang,													// 対応言語
-			'status_img' => $statusImg,												// ユーザからの参照状況
+			'eyecatch_image' => $eyecatchImageTag,									// アイキャッチ画像
+			'status_img' => $statusImg,												// 公開状態
 			'status' => $status,													// 公開状況
 			'category' => $category,											// 記事カテゴリー
 			'view_count' => $totalViewCount,									// 総参照数
