@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2013 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -42,6 +42,7 @@ class blog_mainCommonDef
 	const CF_MESSAGE_NO_ENTRY		= 'message_no_entry';		// ブログ記事が登録されていないメッセージ
 	const CF_MESSAGE_FIND_NO_ENTRY	= 'message_find_no_entry';		// ブログ記事が見つからないメッセージ
 	const CF_TITLE_TAG_LEVEL		= 'title_tag_level';		// タイトルのタグレベル
+	const CF_THUMB_TYPE				= 'thumb_type';				// サムネールタイプ
 	
 	const USER_ID_SEPARATOR = ',';			// ユーザID区切り用セパレータ
 	const ATTACH_FILE_DIR = '/etc/blog';				// 添付ファイル格納ディレクトリ
@@ -131,7 +132,7 @@ class blog_mainCommonDef
 	 * @param timestamp $updateDt	記事の更新日付
 	 * @return string				画像URL
 	 */
-	static function createThumbnail($srcHtml, $entryId, $updateDt)
+/*	static function createThumbnail($srcHtml, $entryId, $updateDt)
 	{
 		global $gEnvManager;
 		global $gInstanceManager;
@@ -167,7 +168,7 @@ class blog_mainCommonDef
 					
 					// 画像格納用のディレクトリ作成
 					$destDir = dirname($thumbPath);
-					if (!file_exists($destDir)) mkdir($destDir, M3_SYSTEM_DIR_PERMISSION, true/*再帰的*/);
+					if (!file_exists($destDir)) mkdir($destDir, M3_SYSTEM_DIR_PERMISSION, true);
 
 					// サムネール作成
 					$ret = $gInstanceManager->getImageManager()->createDefaultThumb(M3_VIEW_TYPE_BLOG, $entryId, $imagePath);
@@ -182,20 +183,128 @@ class blog_mainCommonDef
 			}
 		}
 		return $thumbUrl;
-	}
+	}*/
 	/**
 	 * サムネール画像を削除
 	 *
 	 * @param int    $entryId		ブログ記事ID
 	 * @return bool					true=成功、false=失敗
 	 */
-	static function removeThumbnail($entryId)
+/*	static function removeThumbnail($entryId)
 	{
 		global $gInstanceManager;
 		
 		$thumbPath	= $gInstanceManager->getImageManager()->getDefaultThumbPath(M3_VIEW_TYPE_BLOG, $entryId);
 		if (file_exists($thumbPath)) @unlink($thumbPath);
 		return true;
+	}*/
+	/**
+	 * アイキャッチ用画像のURLを取得
+	 *
+	 * @param string $filenames				作成済みファイル名(「;」区切り)
+	 * @param string $defaultFilenames		作成済みデフォルトファイル名(「;」区切り)
+	 * @param string $thumbTypeDef			サムネール画像タイプ定義(タイプ指定の場合)
+	 * @param string $thumbType				サムネール画像タイプ(s,m,l)(タイプ指定の場合)
+	 * @return string						画像URL
+	 */
+	static function getEyecatchImageUrl($filenames, $defaultFilenames, $thumbTypeDef = '', $thumbType = '')
+	{
+		global $gInstanceManager;
+		static $thumbTypeArray;
+		
+		$thumbUrl = '';
+		if (empty($filenames)) $filenames = $defaultFilenames;		// 記事デフォルト画像
+		if (!empty($filenames)){
+			$thumbFilename = $gInstanceManager->getImageManager()->getSystemThumbFilenameByType($filenames, $thumbTypeDef, $thumbType);
+			if (!empty($thumbFilename)) $thumbUrl = $gInstanceManager->getImageManager()->getSystemThumbUrl(M3_VIEW_TYPE_BLOG, self::$_deviceType, $thumbFilename);
+/*			$thumbFilenameArray = explode(';', $filenames);
+			$defaultThumbFilename = $thumbFilenameArray[count($thumbFilenameArray) -1];	// 最大サイズをデフォルト画像とする
+			
+			if (empty($thumbTypeDef)){			// サイズ指定でないとき
+				$thumbUrl = $gInstanceManager->getImageManager()->getSystemThumbUrl(M3_VIEW_TYPE_BLOG, self::$_deviceType, $defaultThumbFilename);		// 最大サイズ画像
+			} else {						// サイズ指定の場合
+				// コンテンツIDを取得
+				list($contentId, $tmp) = explode('_', $defaultThumbFilename);
+				$thumbFilename = '';
+				if (!isset($thumbTypeArray)) $thumbTypeArray = $gInstanceManager->getImageManager()->parseFormatType($thumbTypeDef);// サムネールタイプ
+
+				if (empty($thumbType)){
+					// サムネールタイプが設定されていない場合は最大サイズを取得
+					$thumbFilename = $contentId . '_' . end($thumbTypeArray);
+				} else {					
+					$thumbFilename = $contentId . '_' . $thumbTypeArray[$thumbType];
+					if (!in_array($thumbFilename, $thumbFilenameArray)) $thumbFilename = '';			// 作成されていない画像の場合はデフォルト画像を設定
+				}
+				if (empty($thumbFilename)) $thumbFilename = $defaultThumbFilename;	// デフォルト画像
+				$thumbUrl = $gInstanceManager->getImageManager()->getSystemThumbUrl(M3_VIEW_TYPE_BLOG, self::$_deviceType, $thumbFilename);
+			}*/
+		}
+		return $thumbUrl;
+	}
+	
+	/**
+	 * アイキャッチ用画像を公開ディレクトリにコピー
+	 *
+	 * @param string    $entryId		記事ID
+	 * @return bool						true=成功、false=失敗
+	 */
+	static function copyEyecatchImageToPublicDir($entryId)
+	{
+		global $gInstanceManager;
+		
+		// 画像ファイル名、フォーマット取得
+		list($filenames, $formats) = $gInstanceManager->getImageManager()->getSystemThumbFilename($entryId, 1/*クロップ画像のみ*/);
+		
+		// 画像を公開ディレクトリにコピー
+		$privateThumbDir = $gInstanceManager->getImageManager()->getSystemPrivateThumbPath(M3_VIEW_TYPE_BLOG, self::$_deviceType);
+		$publicThumbDir = $gInstanceManager->getImageManager()->getSystemThumbPath(M3_VIEW_TYPE_BLOG, self::$_deviceType);
+		$ret = cpFileToDir($privateThumbDir, $filenames, $publicThumbDir);
+		return $ret;
+	}
+	/**
+	 * 公開ディレクトリのアイキャッチ用画像を削除
+	 *
+	 * @param string    $entryId		記事ID
+	 * @return bool						true=成功、false=失敗
+	 */
+	static function removerEyecatchImageInPublicDir($entryId)
+	{
+		global $gInstanceManager;
+		
+		// 画像ファイル名、フォーマット取得
+		list($filenames, $formats) = $gInstanceManager->getImageManager()->getSystemThumbFilename($entryId, 1/*クロップ画像のみ*/);
+		
+		// 公開ディレクトリ内の画像を削除
+		$publicThumbDir = $gInstanceManager->getImageManager()->getSystemThumbPath(M3_VIEW_TYPE_BLOG, self::$_deviceType);
+		for ($i = 0; $i < count($filenames); $i++){
+			$publicThumbPath = $publicThumbDir . DIRECTORY_SEPARATOR . $filenames[$i];
+			if (file_exists($publicThumbPath)) @unlink($publicThumbPath);
+		}
+		return true;
+	}
+	/**
+	 * 公開,非公開ディレクトリのアイキャッチ用画像を削除
+	 *
+	 * @param string    $entryId		記事ID
+	 * @return bool						true=成功、false=失敗
+	 */
+	static function removerEyecatchImage($entryId)
+	{
+		global $gInstanceManager;
+		
+		// 画像ファイル名、フォーマット取得
+		list($filenames, $formats) = $gInstanceManager->getImageManager()->getSystemThumbFilename($entryId, 1/*クロップ画像のみ*/);
+
+		// 公開ディレクトリ、非公開ディレクトリの画像を削除
+		$publicThumbDir = $gInstanceManager->getImageManager()->getSystemThumbPath(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType);
+		$privateThumbDir = $gInstanceManager->getImageManager()->getSystemPrivateThumbPath(M3_VIEW_TYPE_BLOG, blog_mainCommonDef::$_deviceType);
+		for ($i = 0; $i < count($filenames); $i++){
+			$publicThumbPath = $publicThumbDir . DIRECTORY_SEPARATOR . $filenames[$i];
+			$privateThumbPath = $privateThumbDir . DIRECTORY_SEPARATOR . $filenames[$i];
+			if (file_exists($publicThumbPath)) @unlink($publicThumbPath);
+			if (file_exists($privateThumbPath)) @unlink($privateThumbPath);
+		}
+		return true;
 	}
 }
 ?>
