@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2014 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -527,6 +527,50 @@ class blog_mainDb extends BaseDb
 		$ret = $this->endTransaction();
 		return $ret;
 	}
+	/**
+	 * サムネールファイル名の更新
+	 *
+	 * @param string $id			エントリーID
+	 * @param string $langId		言語ID
+	 * @param string $thumbFilename	サムネールファイル名
+	 * @return bool					true = 成功、false = 失敗
+	 */
+	function updateThumbFilename($id, $langId, $thumbFilename)
+	{
+		$serial = $this->getEntrySerialNoByContentId($id, $langId);
+		if (empty($serial)) return false;
+		
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$userId = $this->gEnv->getCurrentUserId();	// 現在のユーザ
+						
+		// トランザクション開始
+		$this->startTransaction();
+		
+		// 指定のシリアルNoのレコードが削除状態でないかチェック
+		$queryStr  = 'SELECT * FROM blog_entry ';
+		$queryStr .=   'WHERE be_serial = ? ';
+		$ret = $this->selectRecord($queryStr, array(intval($serial)), $row);
+		if ($ret){		// 既に登録レコードがあるとき
+			if ($row['be_deleted']){		// レコードが削除されていれば終了
+				$this->endTransaction();
+				return false;
+			}
+		} else {		// 存在しない場合は終了
+			$this->endTransaction();
+			return false;
+		}
+		// 日付を更新
+		$queryStr  = 'UPDATE blog_entry ';
+		$queryStr .=   'SET be_thumb_filename = ?, ';	// サムネールファイル名
+		$queryStr .=     'be_update_user_id = ?, ';
+		$queryStr .=     'be_update_dt = ? ';
+		$queryStr .=   'WHERE be_serial = ?';
+		$this->execStatement($queryStr, array($thumbFilename, $userId, $now, intval($serial)));
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return $ret;
+	}
 	/**
 	 * 記事カテゴリーの更新
 	 *
