@@ -5,7 +5,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2013 Magic3 Project.
+ * @copyright  Copyright 2006-2015 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -16,19 +16,16 @@ header: {
 	// title, prev, next, prevYear, nextYear, today
 	left: 'prev,next today',
 	center: 'title',
-	//right: 'month agendaWeek agendaDay'
+	//right: 'month,agendaWeek,agendaDay'
+	//right: 'month,basicWeek,basicDay'
 	right: ''
 },
-// 最初の曜日
-firstDay: 0, // 0:日曜日、1:月曜日
-// 土曜、日曜を表示
-weekends: true,
-// 週モード (fixed, liquid, variable)
-weekMode: 'fixed',
-// 週数を表示
-weekNumbers: false,
 // コンテンツの高さ(px)
 //contentHeight: 600,
 // カレンダーの縦横比(比率が大きくなると高さが縮む)
 //aspectRatio: 1.35,
+// イベントの表示項目数の制限
+eventLimit: true,	// カラムの高さで制限
+// イベントの時刻表示フォーマット
+timeFormat: 'H(:mm)',
 </patTemplate:tmpl>
