@@ -8,9 +8,9 @@
  *
  * @package    カスタム検索
  * @author     株式会社 毎日メディアサービス
- * @copyright  Copyright 2010-2013 株式会社 毎日メディアサービス.
+ * @copyright  Copyright 2010-2014 株式会社 毎日メディアサービス.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_custom_searchWidgetContainer.php 5969 2013-04-29 13:16:04Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.m-media.co.jp
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -33,6 +33,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 	const DEFAULT_NAME_HEAD = '名称未設定';			// デフォルトの設定名
 	const MESSAGE_NO_USER_CATEGORY = 'カテゴリが登録されていません';			// ユーザ作成コンテンツ用のカテゴリが登録されていないときのメッセージ
 	const DEFAULT_SEARCH_COUNT	= 20;				// デフォルトの検索結果表示数
+	const DEFAULT_RESULT_LENGTH = 200;			// 検索結果コンテンツの文字列最大長
 	
 	/**
 	 * コンストラクタ
@@ -106,6 +107,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 		$name	= $request->trimValueOf('item_name');			// ヘッダタイトル
 		$searchTemplate = $request->valueOf('item_html');		// 検索用テンプレート
 		$resultCount	= $request->valueOf('item_result_count');			// 表示項目数
+		$resultLength	= $request->valueOf('item_result_length');			// テキストサイズ
 		$this->searchTextId = $request->trimValueOf('item_search_text');		// 検索用テキストフィールドのタグID
 		$this->searchButtonId = $request->trimValueOf('item_search_button');		// 検索用ボタンのタグID
 		$this->searchResetId = $request->trimValueOf('item_search_reset');		// 検索エリアリセットボタンのタグID
@@ -120,6 +122,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 		$isTargetEvent = ($request->trimValueOf('item_target_event') == 'on') ? 1 : 0;			// イベント情報を検索対象とするかどうか
 		$isTargetBbs = ($request->trimValueOf('item_target_bbs') == 'on') ? 1 : 0;			// BBSを検索対象とするかどうか
 		$isTargetPhoto = ($request->trimValueOf('item_target_photo') == 'on') ? 1 : 0;			// フォトギャラリーを検索対象とするかどうか
+		$isTargetWiki = ($request->trimValueOf('item_target_wiki') == 'on') ? 1 : 0;			// Wikiを検索対象とするかどうか
 		
 		// カテゴリ項目定義
 		$fieldCount = intval($request->trimValueOf('fieldcount'));		// カテゴリ定義項目数
@@ -153,8 +156,9 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 			// 入力チェック
 			$this->checkInput($name, '名前');
 			if (empty($isTargetContent) && empty($isTargetUser) && empty($isTargetBlog) && empty($isTargetProduct) && empty($isTargetEvent) && 
-					empty($isTargetBbs) && empty($isTargetPhoto)) $this->setUserErrorMsg('検索対象が選択されていません');
+					empty($isTargetBbs) && empty($isTargetPhoto) && empty($isTargetWiki)) $this->setUserErrorMsg('検索対象が選択されていません');
 			$this->checkNumeric($resultCount, '表示件数');
+			$this->checkNumeric($resultLength, 'テキストサイズ');
 			
 			// 設定名の重複チェック
 			for ($i = 0; $i < count($this->paramObj); $i++){
@@ -171,6 +175,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 				$newObj = new stdClass;
 				$newObj->name	= $name;// 表示名
 				$newObj->resultCount	= $resultCount;// 表示件数
+				$newObj->resultLength	= $resultLength;			// テキストサイズ
 				$newObj->searchTemplate = $searchTemplate;		// 検索用テンプレート
 				$newObj->searchTextId = $this->searchTextId;		// 検索用テキストフィールドのタグID
 				$newObj->searchButtonId = $this->searchButtonId;		// 検索用ボタンのタグID
@@ -182,6 +187,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 				$newObj->isTargetEvent = $isTargetEvent;			// イベント情報を検索対象とするかどうか
 				$newObj->isTargetBbs = $isTargetBbs;			// BBSを検索対象とするかどうか
 				$newObj->isTargetPhoto = $isTargetPhoto;			// フォトギャラリーを検索対象とするかどうか
+				$newObj->isTargetWiki = $isTargetWiki;			// Wikiを検索対象とするかどうか
 				$newObj->fieldInfo = $this->fieldInfoArray;			// カテゴリ定義
 				
 				$ret = $this->addPageDefParam($defSerial, $defConfigId, $this->paramObj, $newObj);
@@ -197,8 +203,9 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 		} else if ($act == 'update'){		// 設定更新のとき
 			// 入力値のエラーチェック
 			if (empty($isTargetContent) && empty($isTargetUser) && empty($isTargetBlog) && empty($isTargetProduct) && empty($isTargetEvent) && 
-					empty($isTargetBbs) && empty($isTargetPhoto)) $this->setUserErrorMsg('検索対象が選択されていません');
+					empty($isTargetBbs) && empty($isTargetPhoto) && empty($isTargetWiki)) $this->setUserErrorMsg('検索対象が選択されていません');
 			$this->checkNumeric($resultCount, '表示件数');
+			$this->checkNumeric($resultLength, 'テキストサイズ');
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
 				// 現在の設定値を取得
@@ -206,6 +213,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 				if ($ret){
 					// ウィジェットオブジェクト更新
 					$targetObj->resultCount	= $resultCount;// 表示件数
+					$targetObj->resultLength	= $resultLength;			// テキストサイズ
 					$targetObj->searchTemplate	= $searchTemplate;		// 検索用テンプレート
 					$targetObj->searchTextId = $this->searchTextId;		// 検索用テキストフィールドのタグID
 					$targetObj->searchButtonId = $this->searchButtonId;		// 検索用ボタンのタグID
@@ -217,6 +225,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 					$targetObj->isTargetEvent = $isTargetEvent;			// イベント情報を検索対象とするかどうか
 					$targetObj->isTargetBbs = $isTargetBbs;			// BBSを検索対象とするかどうか
 					$targetObj->isTargetPhoto = $isTargetPhoto;			// フォトギャラリーを検索対象とするかどうか
+					$targetObj->isTargetWiki = $isTargetWiki;			// Wikiを検索対象とするかどうか
 					$targetObj->fieldInfo = $this->fieldInfoArray;			// カテゴリ定義
 				}
 				
@@ -243,6 +252,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 			if ($replaceNew){		// データ再取得時
 				$name = $this->createDefaultName();			// デフォルト登録項目名
 				$resultCount	= self::DEFAULT_SEARCH_COUNT;			// 表示項目数
+				$resultLength	= self::DEFAULT_RESULT_LENGTH;			// テキストサイズ
 				$this->fieldInfoArray = array();			// 項目定義
 				
 				// デフォルトの検索テンプレート作成
@@ -259,6 +269,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 				$isTargetEvent = 1;			// イベント情報を検索対象とするかどうか
 				$isTargetBbs = 1;			// BBSを検索対象とするかどうか
 				$isTargetPhoto = 1;			// フォトギャラリーを検索対象とするかどうか
+				$isTargetWiki = 1;			// Wikiを検索対象とするかどうか
 			}
 			$this->serialNo = 0;
 		} else {		// 更新の場合
@@ -267,6 +278,8 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 				if ($ret){
 					$name = $targetObj->name;// 名前
 					$resultCount	= $targetObj->resultCount;			// 表示項目数
+					$resultLength	= intval($targetObj->resultLength);			// テキストサイズ
+					if ($resultLength <= 0) $resultLength = self::DEFAULT_RESULT_LENGTH;			// テキストサイズ
 					$this->searchTextId = $targetObj->searchTextId;		// 検索用テキストフィールドのタグID
 					$this->searchButtonId = $targetObj->searchButtonId;		// 検索用ボタンのタグID
 					$this->searchResetId = $targetObj->searchResetId;		// 検索エリアリセットボタンのタグID
@@ -277,6 +290,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 					$isTargetEvent = $targetObj->isTargetEvent;			// イベント情報を検索対象とするかどうか
 					$isTargetBbs = $targetObj->isTargetBbs;			// BBSを検索対象とするかどうか
 					$isTargetPhoto = $targetObj->isTargetPhoto;			// フォトギャラリーを検索対象とするかどうか
+					$isTargetWiki = $targetObj->isTargetWiki;			// Wikiを検索対象とするかどうか
 					$searchTemplate = $targetObj->searchTemplate;		// 検索用テンプレート
 					if (!empty($targetObj->fieldInfo)) $this->fieldInfoArray = $targetObj->fieldInfo;			// 項目定義
 				}
@@ -315,6 +329,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 		// 画面にデータを埋め込む
 		$this->tmpl->addVar("item_name_visible", "name", $name);		// 名前
 		$this->tmpl->addVar("_widget", "result_count",	$resultCount);			// 表示項目数
+		$this->tmpl->addVar("_widget", "result_length",	$resultLength);			// テキストサイズ
 		$this->tmpl->addVar("_widget", "html",	$searchTemplate);
 		$this->tmpl->addVar("_widget", "search_text",	$this->searchTextId);		// 検索用テキストフィールドのタグID
 		$this->tmpl->addVar("_widget", "search_button",	$this->searchButtonId);		// 検索用ボタンのタグID
@@ -330,6 +345,7 @@ class admin_custom_searchWidgetContainer extends BaseAdminWidgetContainer
 		if (!empty($isTargetEvent)) $this->tmpl->addVar('_widget', 'target_event_checked', 'checked');			// イベント情報を検索対象とするかどうか
 		if (!empty($isTargetBbs)) $this->tmpl->addVar('_widget', 'target_bbs_checked', 'checked');			// BBSを検索対象とするかどうか
 		if (!empty($isTargetPhoto)) $this->tmpl->addVar('_widget', 'target_photo_checked', 'checked');			// フォトギャラリーを検索対象とするかどうか
+		if (!empty($isTargetWiki)) $this->tmpl->addVar('_widget', 'target_wiki_checked', 'checked');			// Wikiを検索対象とするかどうか
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);// 選択中のシリアル番号、IDを設定
 		
 		// ボタンの表示制御
