@@ -8,14 +8,14 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2008 Magic3 Project.
+ * @copyright  Copyright 2006-2009 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_g_qrcodeWidgetContainer.php 1424 2009-01-07 04:29:09Z fishbone $
+ * @version    SVN: $Id: admin_g_qrcodeWidgetContainer.php 2266 2009-08-28 08:25:59Z fishbone $
  * @link       http://www.magic3.org
  */
-require_once($gEnvManager->getContainerPath() . '/baseWidgetContainer.php');
+require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
 
-class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
+class admin_g_qrcodeWidgetContainer extends BaseAdminWidgetContainer
 {
 	private $sysDb;	// DB接続オブジェクト
 	private $serialNo;		// 選択中の項目のシリアル番号
@@ -101,8 +101,7 @@ class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
 		$name	= $request->trimValueOf('item_name');			// ヘッダタイトル
 		$qrData	= $request->trimValueOf('item_qr_data');		// QRコード化するデータ
 		$desc	= $request->trimValueOf('item_desc');			// 説明
-		$width	= $request->trimValueOf('item_width');			// 画像サイズ
-		$showTitle = ($request->trimValueOf('item_showtitle') == 'on') ? 1 : 0;		// タイトルを表示するかどうか			
+		$width	= $request->trimValueOf('item_width');			// 画像サイズ		
 		$this->configId = $request->trimValueOf('item_id');		// 定義ID
 		if (empty($this->configId)) $this->configId = $defConfigId;		// 呼び出しウィンドウから引き継いだ定義ID
 				
@@ -144,7 +143,6 @@ class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
 				$newObj->qrData	= $qrData;		// QRコード化するデータ
 				$newObj->desc	= $desc;		// 説明
 				$newObj->width	= $width;		// 画像サイズ
-				$newObj->showTitle = $showTitle;					// タイトルを表示するかどうか
 				$this->paramObj[] = $newObj;
 			
 				// ウィジェットパラメータオブジェクト更新
@@ -181,7 +179,6 @@ class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
 						$targetObj->qrData	= $qrData;		// QRコード化するデータ
 						$targetObj->desc	= $desc;		// 説明
 						$targetObj->width	= $width;		// 画像サイズ
-						$targetObj->showTitle = $showTitle;					// タイトルを表示するかどうか
 						break;
 					}
 				}
@@ -218,7 +215,6 @@ class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
 			$qrData	= $gEnvManager->getDefaultMobileUrl();		// QRコード化するデータ
 			$desc	= '';		// 説明
 			$width	= self::DEFAULT_WIDTH;		// 幅
-			$showTitle = 1;					// タイトルを表示するかどうか
 			$this->serialNo = 0;
 		} else {
 			// 定義からウィジェットパラメータを検索して、定義データを取得
@@ -234,7 +230,6 @@ class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
 					$qrData	= $targetObj->qrData;		// QRコード化するデータ
 					$desc	= $targetObj->desc;			// 説明
 					$width	= $targetObj->width;		// 画像サイズ
-					$showTitle = $targetObj->showTitle;					// タイトルを表示するかどうか
 				}
 				$this->serialNo = $this->configId;
 				
@@ -249,14 +244,8 @@ class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "desc",	$desc);
 		$this->tmpl->addVar("_widget", "width",	$width);		// 画像サイズ
 		$checked = '';
-		if ($showTitle) $checked = 'checked';
-		$this->tmpl->addVar("_widget", "show_title", $checked);	// タイトルを表示するかどうか
+
 		// プレビュー
-		// タイトルの設定
-		if ($showTitle){		// タイトル表示のとき
-			$titleString = '<tr><th>' . $name . '</th></tr>';
-			$this->tmpl->addVar("_widget", "preview_title", $titleString);
-		}
 		// 説明の設定
 		if (!empty($desc)){
 			$descString = '<tr><td>' . $desc . '</td></tr>';
@@ -267,8 +256,6 @@ class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
 		$this->tmpl->addVar("_widget", "preview_qr_data",	urlencode($qrData));
 				
 		$this->tmpl->addVar("_widget", "serial", $this->serialNo);// 選択中のシリアル番号、IDを設定
-		$this->tmpl->addVar("_widget", "widget_url", $gEnvManager->getCurrentWidgetRootUrl());	// ウィジェットのルートディレクトリ
-		$this->tmpl->addVar("_widget", "root_url", $gEnvManager->getRootUrl());
 		
 		// 画面定義用の情報を戻す
 		$this->tmpl->addVar("_widget", "def_serial", $defSerial);	// ページ定義のレコードシリアル番号
@@ -389,7 +376,6 @@ class admin_g_qrcodeWidgetContainer extends BaseWidgetContainer
 		$this->createItemList();
 		
 		$this->tmpl->addVar("_widget", "serial_list", implode($this->serialArray, ','));// 表示項目のシリアル番号を設定
-		$this->tmpl->addVar('_widget', 'admin_url', $gEnvManager->getDefaultAdminUrl());// 管理者URL
 		
 		// 画面定義用の情報を戻す
 		$this->tmpl->addVar("_widget", "def_serial", $defSerial);	// ページ定義のレコードシリアル番号
