@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m_bbs_2chTopWidgetContainer.php 4033 2011-03-18 01:43:53Z fishbone $
+ * @version    SVN: $Id: m_bbs_2chTopWidgetContainer.php 4039 2011-03-21 05:37:18Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/m_bbs_2chBaseWidgetContainer.php');
@@ -73,8 +73,8 @@ class m_bbs_2chTopWidgetContainer extends m_bbs_2chBaseWidgetContainer
 		$act = $request->trimValueOf('act');
 		$postTicket = $request->trimValueOf('ticket');		// POST確認用
 		$this->threadId = $request->trimValueOf(M3_REQUEST_PARAM_BBS_THREAD_ID);	// スレッドID
-		$message = $request->valueOf('bbs_message');// 投稿メッセージ
-		$name = $request->trimValueOf('bbs_name');// 名前
+		$message = $request->mobileTrimValueOf('bbs_message');// 投稿メッセージ
+		$name = $request->mobileTrimValueOf('bbs_name');// 名前
 		$email = $request->trimValueOf('bbs_email');// Eメールアドレス
 		
 		if ($act == 'add'){		// 投稿追加のとき
@@ -126,6 +126,8 @@ class m_bbs_2chTopWidgetContainer extends m_bbs_2chBaseWidgetContainer
 					$this->bbsEmail = $email;		// 入力再設定用(Eメールアドレス)
 					$this->bbsMessage = $message;		// 入力再設定用(投稿メッセージ)
 				}
+			} else {
+				$this->setMsg(self::MSG_APP_ERR, '不正な投稿により、書きこみに失敗しました。');
 			}
 			$request->unsetSessionValue(M3_SESSION_POST_TICKET);		// セッション値をクリア
 		}
@@ -182,6 +184,9 @@ class m_bbs_2chTopWidgetContainer extends m_bbs_2chBaseWidgetContainer
 		if (is_null($bottomMessage)) $bottomMessage = self::DEFAULT_BOTTOM_MESSAGE;
 		$this->tmpl->addVar("_widget", "bottom_message", $bottomMessage);
 		
+		// 送信先
+		$this->tmpl->addVar("_widget", "post_url", $this->_currentPageUrl);
+				
 		// その他
 		$this->tmpl->addVar("_widget", "ad", "");		// 広告バナー等
 		$this->tmpl->addVar("_widget", "spacer", "$this->_spacer");		// スペーサ
@@ -201,7 +206,7 @@ class m_bbs_2chTopWidgetContainer extends m_bbs_2chBaseWidgetContainer
 		$subject = $fetchedRow['th_subject'] . '(' . $fetchedRow['th_message_count'] . ')';
 		$threadLinkUrl = $this->_currentPageUrl . '&' . M3_REQUEST_PARAM_BBS_THREAD_ID . '=' . $fetchedRow['th_id'] . '&' . M3_REQUEST_PARAM_LIST_NO . '=l' . self::DEFAULT_LAST_MESSAGE_COUNT;
 		if ($index < $this->threadCount){
-			$subject = $no . ':</a> <a href="#' . $no . '">' . $this->convertToDispString($subject);
+			$subject = $no . ':</a><a href="#' . $no . '">' . $this->convertToDispString($subject);
 			
 			// スレッドIDを追加
 			$this->threadIdArray[] = $fetchedRow['th_id'];
@@ -209,7 +214,7 @@ class m_bbs_2chTopWidgetContainer extends m_bbs_2chBaseWidgetContainer
 			// スレッド情報を追加
 			$this->threadInfoArray[] = $fetchedRow;
 		} else {
-			$subject = $no . ': ' . $this->convertToDispString($subject);
+			$subject = $no . ':' . $this->convertToDispString($subject);
 		}
 		
 		$row = array(
@@ -248,9 +253,9 @@ class m_bbs_2chTopWidgetContainer extends m_bbs_2chBaseWidgetContainer
 		if (empty($name)) $name = $this->_configArray[self::CF_NONAME_NAME];				// 名前未設定時の表示名
 		$email = $this->convertToDispString($fetchedRow['te_email']);			// Eメール
 		if (!empty($email) && !empty($this->createEmailLink)){			// Eメールリンク作成のとき
-			$name = '<a href="mailto:' . $email . '"><b>' . $name . ' </b></a>';
+			$name = '<a href="mailto:' . $email . '">' . $name . '</a>';
 		} else {
-			$name = '<font color="' . $this->nameColor . '"><b>' . $name . ' </b></font>';
+			$name = '<span style="color:' . $this->nameColor . ';">' . $name . '</span>';
 		}
 		
 		// 日付作成
@@ -338,6 +343,7 @@ class m_bbs_2chTopWidgetContainer extends m_bbs_2chBaseWidgetContainer
 				'thread50_url'	=> $this->convertUrlToHtmlEntity($this->getUrl($thread50Url, true)),				// スレッド最新50表示URL
 				'thread100_url'	=> $this->convertUrlToHtmlEntity($this->getUrl($thread100Url, true)),				// スレッド100まで表示URL
 				'reload_url'	=> $this->convertUrlToHtmlEntity($this->getUrl($reloadUrl, true)),					// 画面再表示
+				'post_url'		=> $this->_currentPageUrl,		// POST先URL
 				'ticket'		=> $this->ticket,		// POST確認用ハッシュキー
 				'spacer'		=> $this->_spacer	// スペーサ
 			);
