@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2014 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: reg_userLoginWidgetContainer.php 5207 2012-09-14 05:10:45Z fishbone $
+ * @version    SVN: $Id$
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/reg_userBaseWidgetContainer.php');
@@ -41,7 +41,11 @@ class reg_userLoginWidgetContainer extends reg_userBaseWidgetContainer
 	 */
 	function _setTemplate($request, &$param)
 	{
-		return 'login.tmpl.html';
+		if ($this->_renderType == M3_RENDER_BOOTSTRAP){			// Bootstrap型テンプレートのとき
+			return 'login_bootstrap.tmpl.html';
+		} else {
+			return 'login.tmpl.html';
+		}
 	}
 	/**
 	 * テンプレートにデータ埋め込む
