@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_reserve_mainWidgetContainer.php 489 2008-04-09 07:53:47Z fishbone $
+ * @version    SVN: $Id: admin_reserve_mainWidgetContainer.php 2939 2010-03-17 14:20:34Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() . '/admin_reserve_mainBaseWidgetContainer.php');
@@ -72,7 +72,7 @@ class admin_reserve_mainWidgetContainer extends admin_reserve_mainBaseWidgetCont
 			$gLaunchManager->goSubWidget($task, true);		// 管理者機能で呼び出し
 			return false;
 		} else {
-			$this->SetMsg(0, "画面が見つかりません");
+			$this->SetMsg(self::MSG_APP_ERR, "画面が見つかりません");
 			return true;
 		}
 	}
