@@ -10,12 +10,12 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2008 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: reserve_mainReserveWidgetContainer.php 563 2008-04-30 09:25:56Z fishbone $
+ * @version    SVN: $Id: reserve_mainReserveWidgetContainer.php 5056 2012-07-23 02:50:32Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() .			'/baseWidgetContainer.php');
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/reserve_mainDb.php');
-require_once($gEnvManager->getLibPath()			. '/Calendar-0.5.3/Month/Weekdays.php');
+require_once(CALENDAR_ROOT			. 'Month/Weekdays.php');
 
 class reserve_mainReserveWidgetContainer extends BaseWidgetContainer
 {
