@@ -508,6 +508,8 @@ $_rename_messages  = array(
 	'msg_title'      => 'Rename page',
 	'msg_page'       => 'specify source page name',
 	'msg_regex'      => 'rename with regular expressions.',
+	'msg_from'       => 'from',
+	'msg_to'         => 'to',
 	'msg_related'    => 'related pages',
 	'msg_do_related' => 'A related page is also renamed.',
 	'msg_rename'     => 'rename %s',
