@@ -510,6 +510,8 @@ $_rename_messages  = array(
 	'msg_title'      => 'ページ名の変更',
 	'msg_page'       => '変更元ページを指定',
 	'msg_regex'      => '正規表現で置換',
+	'msg_from'       => '変更元',
+	'msg_to'         => '変更先',
 	'msg_related'    => '関連ページ',
 	'msg_do_related' => '関連ページもリネームする',
 	'msg_rename'     => '%sの名前を変更します。',
